@@ -111,7 +111,7 @@ typedef struct knh_Nue_t {
 typedef struct {
 	union {
 		knh_boolean_t bvalue;
-		knh_integer_t ivalue;
+		knh_int_t ivalue;
 		knh_float_t   fvalue;
 		knh_uint64_t  data;
 	};
@@ -214,11 +214,11 @@ typedef struct knh_Array_t {
 /* @class IArray Object knh_IArray_t @Cyclic @Param1 */
 /* @flag IArray.Dim ARY:1 (%s)->h.flag 'is:set:*:*' */
 
-#define KNH_IARRAY_INITSIZE  (KONOHA_SMALLPAGESIZE / sizeof(knh_integer_t))
+#define KNH_IARRAY_INITSIZE  (KONOHA_SMALLPAGESIZE / sizeof(knh_int_t))
 
 typedef struct knh_IArray_t {
 	knh_hObject_t h;
-	knh_integer_t *ilist;
+	knh_int_t *ilist;
 	size_t size;
 	size_t capacity;
 } knh_IArray_t;
@@ -273,7 +273,7 @@ typedef struct knh_dict_t {
 	struct knh_String_t *key;
 	union {
 		Object *_unused;
-		knh_uint_t _unused_int;
+		knh_uintptr_t _unused_int;
 	};
 } knh_dict_t;
 
@@ -296,7 +296,7 @@ typedef struct knh_DictMap_t {
 
 typedef struct knh_dictsete_t {
 	struct knh_String_t *key;
-	knh_uint_t value;
+	knh_uintptr_t value;
 } knh_dictsete_t;
 
 typedef struct knh_DictSet_t {
@@ -317,7 +317,7 @@ typedef struct knh_hashentry_t {
 	Object *key;
 	union {
 		Object *value;
-		knh_uint_t uvalue;
+		knh_uintptr_t uvalue;
 	};
 } knh_hashentry_t;
 
@@ -368,22 +368,22 @@ typedef struct knh_DictIdx_t {
 	knh_hObject_t h;
 	struct knh_Array_t *terms;
 	struct knh_DictSet_t *termsDictSet;
-	knh_int_t offset;
+	knh_intptr_t offset;
 } knh_DictIdx_t;
 
 /* ------------------------------------------------------------------------ */
 /* ------------------------------------------------------------------------ */
 /* @class Class Object knh_Class_t */
-/* @flag Class.Release!Debug CF ctx->tClass[(%s)].cflag 'is:*:is:*' */
-/* @flag Class.Immutable CF ctx->tClass[(%s)].cflag 'is:*:is:*' */
-/* @flag Class.Cyclic CF ctx->tClass[(%s)].cflag 'is:set:*:*' */
-/* @flag Class.MetaExtensible CF ctx->tClass[(%s)].cflag 'is:*:is:*' */
-/* @flag Class.Private!Public CF ctx->tClass[(%s)].cflag 'is:*:is:*' */
-/* @flag Class.Final CF ctx->tClass[(%s)].cflag 'is:*:is:*' */
-/* @flag Class.Singleton CF ctx->tClass[(%s)].cflag 'is:*:*:*' */
-/* @ flag Class.System CF ctx->tClass[(%s)].cflag 'is:*:is:*' */
-/* @flag Class.NullObject CF ctx->tClass[(%s)].cflag 'is:*:*:*' */
-/* @flag Class.Interface  CF ctx->tClass[(%s)].cflag 'is:*:is:*' */
+/* @flag Class.Release!Debug CF ctx->share->ClassTable[(%s)].cflag 'is:*:is:*' */
+/* @flag Class.Immutable CF ctx->share->ClassTable[(%s)].cflag 'is:*:is:*' */
+/* @flag Class.Cyclic CF ctx->share->ClassTable[(%s)].cflag 'is:set:*:*' */
+/* @flag Class.MetaExtensible CF ctx->share->ClassTable[(%s)].cflag 'is:*:is:*' */
+/* @flag Class.Private!Public CF ctx->share->ClassTable[(%s)].cflag 'is:*:is:*' */
+/* @flag Class.Final CF ctx->share->ClassTable[(%s)].cflag 'is:*:is:*' */
+/* @flag Class.Singleton CF ctx->share->ClassTable[(%s)].cflag 'is:*:*:*' */
+/* @ flag Class.System CF ctx->share->ClassTable[(%s)].cflag 'is:*:is:*' */
+/* @flag Class.NullObject CF ctx->share->ClassTable[(%s)].cflag 'is:*:*:*' */
+/* @flag Class.Interface  CF ctx->share->ClassTable[(%s)].cflag 'is:*:is:*' */
 
 typedef struct knh_Class_t {
 	knh_hObject_t h;
@@ -424,16 +424,21 @@ typedef struct knh_ClassStruct_t {
 /* ------------------------------------------------------------------------ */
 /* @class MethodField Object knh_MethodField_t @Private */
 
-typedef struct knh_mfield_t {
+typedef struct {
 	knh_type_t    type;
 	knh_fieldn_t  fn;
-} knh_mfield_t ;
+} knh_mparam_t ;
+
+#define KNH_METHODFIELD_2  2
 
 typedef struct knh_MethodField_t {
 	knh_hObject_t h;
-	knh_mfield_t* params;
-	knh_ushort_t size;
-	knh_ushort_t rsize;
+	knh_type_t rtype; 	knh_ushort_t psize;
+	union {
+		knh_mparam_t* mparams;
+		knh_mparam_t  p0;
+	};
+	knh_mparam_t p1;
 } knh_MethodField_t;
 
 /* ------------------------------------------------------------------------ */
@@ -517,6 +522,8 @@ typedef struct knh_AffineConv_t {
 /* ------------------------------------------------------------------------ */
 /* IntSpec, FloatSpec, StringSpec */
 
+#define KNH_CLASSSPEC_FMT    "%s{%s}"
+
 typedef struct {
 	knh_flag_t  flag;
 	knh_class_t cid;
@@ -538,18 +545,18 @@ typedef knh_ClassSpec_t* (*knh_fspec)(Ctx *ctx, knh_class_t bcid, char *extra);
 /* @flag IntUnit.Unsigned UF DP((IntUnit*)%s)->spec.flag 'is:*:is:*' */
 
 struct  knh_IntUnit_t;
-typedef knh_bool_t (*knh_fenumchk)(struct knh_IntUnit_t *, knh_integer_t v);
-typedef int (*knh_fenumcmp)(struct knh_IntUnit_t *, knh_integer_t v1, knh_integer_t v2);
-typedef void (*knh_fenumfmt)(struct knh_IntUnit_t *, char *buf, size_t bufsiz, knh_integer_t v);
+typedef knh_bool_t (*knh_fenumchk)(struct knh_IntUnit_t *, knh_int_t v);
+typedef int (*knh_fenumcmp)(struct knh_IntUnit_t *, knh_int_t v1, knh_int_t v2);
+typedef void (*knh_fenumfmt)(struct knh_IntUnit_t *, char *buf, size_t bufsiz, knh_int_t v);
 
 typedef struct knh_IntUnit {
 	knh_hClassSpec_struct spec;
 	knh_fenumchk fchk;
 	knh_fenumcmp fcmp;
 	knh_fenumfmt ffmt;
-	knh_integer_t min;
-	knh_integer_t max;
-	knh_integer_t step;
+	knh_int_t min;
+	knh_int_t max;
+	knh_int_t step;
 } knh_IntUnit_struct;
 
 /* ------------------------------------------------------------------------ */
@@ -792,32 +799,32 @@ typedef struct knh_NameSpace {
 /* @class System Object knh_System_struct @Singleton */
 
 typedef struct knh_System {
-	knh_uint_t sysid;
+	knh_uintptr_t sysid;
 	size_t     ctxcount;
 
-	struct knh_NameSpace_t* ns;
-	struct knh_DictMap_t* props;
+	struct knh_NameSpace_t*    ns;
+	struct knh_DictMap_t*      props;
 	struct knh_InputStream_t*  in;
 	struct knh_OutputStream_t* out;
 	struct knh_OutputStream_t* err;
 	struct knh_String_t*       enc;
-	struct knh_DictIdx_t *tfileidDictIdx;
-	struct knh_DictIdx_t *tfieldnDictIdx;
-	struct knh_Array_t   *tMethodFields;
-	struct knh_DictMap_t *tConstDictMap;
-	knh_String_t         *homeDir;
-	struct knh_DictMap_t *sysnsDictMap;
-	struct knh_DictSet_t *funcDictSet;
-	struct knh_DictSet_t *drvapiDictSet;
-	struct knh_DictSet_t *makespecDictSet;
+	knh_String_t              *homeDir;
 
-	struct knh_DictSet_t *texptNameDictSet;
+	struct knh_DictMap_t *GlobalConstDictMap;
+	struct knh_DictIdx_t *FileNameDictIdx;
+	struct knh_DictIdx_t *FieldNameDictIdx;
+	struct knh_HashMap_t* MethodFieldHashMap;
+	struct knh_DictSet_t *ExptNameDictSet;
+	struct knh_DictMap_t* NameSpaceTableDictMap;
+	struct knh_DictMap_t* URNAliasDictMap;
+	struct knh_DictSet_t *DriversTableDictSet;
+	struct knh_DictSet_t *SpecFuncDictSet;
+	struct knh_Array_t   *UsingResources;
+
+
+	struct knh_DictMap_t *sysnsDictMap_UNUSED;
+	struct knh_DictSet_t *funcDictSet_UNUSED;
 
-	struct knh_HashMap_t* tmetaHashMap;
-	struct knh_DictMap_t* tnameSpaceDictMap;
-	struct knh_DictMap_t* turnAliasDictMap;
-	/* lock */
-	knh_mutex_t           mutex;
 } knh_System_struct;
 
 /* ------------------------------------------------------------------------ */
