@@ -76,7 +76,7 @@ void knh_Context_setEncoding(Ctx *ctx, knh_Context_t *o, String *enc);
 AffineConv *new_AffineConv(Ctx *ctx, knh_float_t fa, knh_float_t fb);
 /* ../src/class/knh_Array.c */
 size_t knh_array_newsize(size_t newsize, size_t usize);
-size_t knh_array_index(Ctx *ctx, knh_int_t n, size_t size);
+size_t knh_array_index(Ctx *ctx, knh_intptr_t n, size_t size);
 void knh_Array_grow(Ctx *ctx, Array *a, size_t newsize, Object *v);
 knh_Array_t* new_Array0(Ctx *ctx, size_t capacity);
 Object** knh_Array_list(Array *o);
@@ -93,8 +93,8 @@ void knh_Bytes_unputc(Bytes *o);
 size_t knh_size(size_t s);
 knh_bytes_t knh_bytes_subset(knh_bytes_t t, size_t s, size_t e);
 knh_bytes_t knh_bytes_offlen(knh_bytes_t t, size_t off, size_t len);
-knh_bytes_t knh_bytes_trim(knh_bytes_t t, knh_int_t ch);
-int knh_bytes_parseinteger(knh_bytes_t t, knh_integer_t *value);
+knh_bytes_t knh_bytes_trim(knh_bytes_t t, knh_intptr_t ch);
+int knh_bytes_parseinteger(knh_bytes_t t, knh_int_t *value);
 int knh_bytes_parsefloat(knh_bytes_t t, knh_float_t *value);
 /* ../src/class/knh_BytesConv.c */
 size_t knh_BytesConv_conv(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba);
@@ -107,13 +107,14 @@ String *new_String__cwbconv(Ctx *ctx, knh_cwb_t cwb, BytesConv *bc);
 void knh_OutputStream_write__bconv(Ctx *ctx, OutputStream *w, knh_bytes_t t);
 void knh_BytesConv__k(Ctx *ctx, BytesConv *o, OutputStream *w, String *m);
 /* ../src/class/knh_Class.c */
-knh_class_t knh_tClass_newId(Ctx *ctx);
-void konoha_setClassName(Ctx *ctx, knh_class_t cid, String *lname);
-char *knh_tClass_CLASSN(Ctx *ctx, knh_class_t cid);
-void konoha_setClassDefaultValue(Ctx *ctx, knh_class_t cid, Object *value, knh_fdefault fdefault);
-Object *konoha_getClassDefaultValue(Ctx *ctx, knh_class_t cid);
+knh_struct_t knh_StructTable_newId(Ctx *ctx);
+knh_class_t knh_ClassTable_newId(Ctx *ctx);
+void konoha_seClassTableName(Ctx *ctx, knh_class_t cid, String *lname);
+char *knh_ClassTable_CLASSN(Ctx *ctx, knh_class_t cid);
+void konoha_seClassTableDefaultValue(Ctx *ctx, knh_class_t cid, Object *value, knh_fdefault fdefault);
+Object *konoha_geClassTableDefaultValue(Ctx *ctx, knh_class_t cid);
 Object *konoha_getDefaultValue(Ctx *ctx, knh_type_t type);
-void konoha_setClassParam(Ctx *ctx, knh_class_t cid, knh_class_t p1, knh_class_t p2);
+void konoha_seClassTableParam(Ctx *ctx, knh_class_t cid, knh_class_t p1, knh_class_t p2);
 knh_class_t konoha_addGenericsClass(Ctx *ctx, knh_class_t cid, String *name, knh_class_t bcid, knh_class_t p1, knh_class_t p2);
 ClassStruct* new_ClassStruct0(Ctx *ctx, int field_size, int method_size);
 knh_index_t knh_Class_indexOfField(Ctx *ctx, knh_class_t cid, knh_fieldn_t fn);
@@ -122,7 +123,7 @@ knh_cfield_t *knh_Class_fieldAt(Ctx *ctx, knh_class_t cid, size_t n);
 void knh_cfield_dump(Ctx *ctx, knh_cfield_t *f, size_t offset, size_t fsize, OutputStream *w);
 ClassMap* new_ClassMap0(Ctx *ctx, knh_ushort_t capacity);
 int knh_ClassMap_isDefault(Ctx *ctx, ClassMap *o);
-void knh_tClass_readyClassMap(Ctx *ctx, knh_class_t cid);
+void knh_ClassTable_readyClassMap(Ctx *ctx, knh_class_t cid);
 void knh_ClassMap_resize(Ctx *ctx, ClassMap *o, size_t newsize);
 int knh_ClassMap_util_cmp(const Mapper *m1, const Mapper *m2);
 void knh_ClassMap_sort(Ctx *ctx, ClassMap *o);
@@ -160,15 +161,15 @@ void knh_cwb_clear(knh_cwb_t cwb);
 String *new_String__cwb(Ctx *ctx, knh_cwb_t cwb);
 String *new_StringX__cwb(Ctx *ctx, knh_class_t cid, knh_cwb_t cwb);
 /* ../src/class/knh_DictIdx.c */
-DictIdx* new_DictIdx0(Ctx *ctx, size_t init, knh_int_t offset);
-DictIdx* new_DictIdx0__ignoreCase(Ctx *ctx, size_t init, knh_int_t offset);
+DictIdx* new_DictIdx0(Ctx *ctx, size_t init, knh_intptr_t offset);
+DictIdx* new_DictIdx0__ignoreCase(Ctx *ctx, size_t init, knh_intptr_t offset);
 size_t knh_DictIdx_size(DictIdx *o);
 knh_index_t knh_DictIdx_index(Ctx *ctx, DictIdx *o, knh_bytes_t v);
 knh_index_t knh_DictIdx_add__fast(Ctx *ctx, DictIdx *o, String *term);
 knh_index_t knh_DictIdx_add(Ctx *ctx, DictIdx *o, String *term);
 knh_index_t knh_DictIdx_add__b(Ctx *ctx, DictIdx *o, knh_bytes_t term);
-String* knh_DictIdx_get__fast(DictIdx *o, knh_int_t termid);
-String* knh_DictIdx_get(Ctx *ctx, DictIdx *o, knh_int_t termid);
+String* knh_DictIdx_get__fast(DictIdx *o, knh_intptr_t termid);
+String* knh_DictIdx_get(Ctx *ctx, DictIdx *o, knh_intptr_t termid);
 void knh_DictIdx_clear(Ctx *ctx, DictIdx *o);
 void knh_DictIdx__k(Ctx *ctx, DictIdx *o, OutputStream *w, String *m);
 /* ../src/class/knh_DictMapSet.c */
@@ -179,8 +180,8 @@ void knh_DictSet_sort(DictSet *o);
 void knh_DictMap_toIgnoreCase(DictMap *o);
 void knh_DictSet_toIgnoreCase(DictSet *o);
 knh_dict_t *knh_dictmap_malloc(Ctx *ctx, size_t init);
-DictMap* new_DictMap0(Ctx *ctx, knh_int_t capacity);
-DictMap* new_DictMap(Ctx *ctx, knh_class_t p1, knh_int_t capacity);
+DictMap* new_DictMap0(Ctx *ctx, knh_intptr_t capacity);
+DictMap* new_DictMap(Ctx *ctx, knh_class_t p1, knh_intptr_t capacity);
 size_t knh_DictMap_size(DictMap *o);
 String* knh_DictMap_keyAt(DictMap *o, size_t n);
 Object* knh_DictMap_valueAt(DictMap *o, size_t n);
@@ -194,21 +195,21 @@ void knh_DictMap_set(Ctx *ctx, DictMap *o, String *key, Any *v);
 void knh_DictMap_remove(Ctx *ctx, DictMap *o, String *key);
 void knh_DictMap_clear(Ctx *ctx, DictMap *o);
 knh_dict_t *knh_dictset_malloc(Ctx *ctx, size_t init);
-DictSet* new_DictSet0(Ctx *ctx, knh_int_t capacity);
+DictSet* new_DictSet0(Ctx *ctx, knh_intptr_t capacity);
 size_t knh_DictSet_size(DictSet *o);
 String* knh_DictSet_keyAt(DictSet *o, size_t n);
-knh_uint_t knh_DictSet_valueAt(DictSet *o, size_t n);
+knh_uintptr_t knh_DictSet_valueAt(DictSet *o, size_t n);
 void knh_DictSet_removeAt(Ctx *ctx, DictSet *o, size_t n);
 String *new_String__DictSet(Ctx *ctx, DictSet *o, knh_bytes_t key);
-knh_uint_t knh_DictSet_get__b(DictSet *o, knh_bytes_t key);
-knh_uint_t knh_DictSet_get(Ctx *ctx, DictSet *o, String *key);
-void knh_DictSet_append(Ctx *ctx, DictSet *o, String *key, knh_uint_t n);
-void knh_DictSet_set(Ctx *ctx, DictSet *o, String *key, knh_uint_t n);
+knh_uintptr_t knh_DictSet_get__b(DictSet *o, knh_bytes_t key);
+knh_uintptr_t knh_DictSet_get(Ctx *ctx, DictSet *o, String *key);
+void knh_DictSet_append(Ctx *ctx, DictSet *o, String *key, knh_uintptr_t n);
+void knh_DictSet_set(Ctx *ctx, DictSet *o, String *key, knh_uintptr_t n);
 void knh_DictSet_add(Ctx *ctx, DictSet *o, String *key);
 void knh_DictSet_remove(Ctx *ctx, DictSet *o, String *key);
 void knh_DictSet_clear(Ctx *ctx, DictSet *o);
 /* ../src/class/knh_Exception.c */
-String *knh_tExpt_name(Ctx *ctx, knh_expt_t eid);
+String *knh_ExptTable_name(Ctx *ctx, knh_expt_t eid);
 knh_expt_t konoha_addException(Ctx *ctx, knh_flag_t flag, knh_class_t eid, String *name, char *pname);
 Exception* knh_Exception_new__init(Ctx *ctx, Exception *o, String *e, String *msg, Object *bag);
 int knh_Exception_isa(Ctx *ctx, Exception *o, String *msg);
@@ -229,11 +230,11 @@ knh_hashentry_t *knh_hashentry_at(knh_Hash_t *o, size_t n);
 HashMap* new_HashMap(Ctx *ctx, char *name, size_t capacity);
 knh_hashentry_t *knh_Hash_get__hcode(Ctx *ctx, knh_Hash_t *o, knh_hcode_t hcode);
 Object *knh_HashMap_get__hcode(Ctx *ctx, HashMap *o, knh_hcode_t hcode);
-knh_uint_t knh_HashSet_get__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode);
+knh_uintptr_t knh_HashSet_get__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode);
 void knh_Hash_remove__hcode(Ctx *ctx, knh_Hash_t *o, knh_hcode_t hcode);
 void knh_Hash_rehash(Ctx *ctx, knh_Hash_t *o);
 void knh_HashMap_set__hcode(Ctx *ctx, HashMap *o, knh_hcode_t hcode, Any *value);
-void knh_HashSet_set__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode, knh_uint_t uvalue);
+void knh_HashSet_set__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode, knh_uintptr_t uvalue);
 /* ../src/class/knh_InputStream.c */
 Object *knh_InputStream_open(Ctx *ctx, InputStream *o, String *urn);
 int knh_InputStream_getc(Ctx *ctx, InputStream *o);
@@ -243,14 +244,14 @@ void knh_InputStream_close(Ctx *ctx, InputStream *o);
 int knh_InputStream_isClosed(InputStream *o);
 MAPPER knh_Bytes_InputStream(Ctx *ctx, knh_sfp_t *sfp);
 /* ../src/class/knh_Int.c */
-Int* new_Int(Ctx *ctx, knh_integer_t value);
-Int* new_IntX__fast(Ctx *ctx, knh_class_t cid, knh_integer_t value);
-Int *new_IntX(Ctx *ctx, knh_class_t cid, knh_integer_t value);
-knh_integer_t knh_IntNULL_toint(Int *v);
+Int* new_Int(Ctx *ctx, knh_int_t value);
+Int* new_IntX__fast(Ctx *ctx, knh_class_t cid, knh_int_t value);
+Int *new_IntX(Ctx *ctx, knh_class_t cid, knh_int_t value);
+knh_int_t knh_IntNULL_toint(Int *v);
 /* ../src/class/knh_IntUnit.c */
-void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_integer_t min, knh_integer_t max);
-void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_integer_t v);
-IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_integer_t min, knh_integer_t max, knh_integer_t defvalue);
+void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_int_t min, knh_int_t max);
+void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_int_t v);
+IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_int_t min, knh_int_t max, knh_int_t defvalue);
 void knh_IntUnit_initId(Ctx *ctx, IntUnit *b, knh_flag_t flag, knh_class_t cid, String *urn, String *tag);
 /* ../src/class/knh_Iterator.c */
 void knh_Iterator_close(Ctx *ctx, Iterator *it);
@@ -260,12 +261,14 @@ Mapper* new_Mapper(Ctx *ctx, knh_flag_t flag, knh_class_t scid, knh_class_t tcid
 Mapper* new_MapMap(Ctx *ctx, Mapper *m1, Mapper *m2);
 void knh_Mapper__k(Ctx *ctx, Mapper *o, OutputStream *w, String *m);
 /* ../src/class/knh_Method.c */
-MethodField* new_MethodField(Ctx *ctx, size_t size);
+MethodField* new_MethodField(Ctx *ctx, knh_type_t rtype, size_t psize);
+knh_hcode_t knh_mparam_hcode(knh_hcode_t h, knh_type_t type, knh_fieldn_t fn);
+void knh_MethodField_set(MethodField *o, size_t n, knh_type_t type, knh_fieldn_t fn);
 knh_type_t knh_MethodField_pztype(MethodField *o, size_t n);
-knh_mfield_t knh_MethodField_pfield(MethodField *o, size_t n);
+knh_mparam_t knh_MethodField_param(MethodField *o, size_t n);
 knh_type_t knh_Method_rtype(Ctx *ctx, knh_class_t cid, Method *mtd);
 knh_type_t knh_Method_ptype(Ctx *ctx, knh_class_t cid, Method *o, size_t n);
-knh_mfield_t knh_Method_pfield(Method *o, size_t n);
+knh_mparam_t knh_Method_param(Method *o, size_t n);
 int knh_MethodField_equalsType(MethodField *o, MethodField *o2);
 METHOD knh_fmethod_abstract(Ctx *ctx, knh_sfp_t *sfp);
 knh_bool_t knh_Method_isAbstract(Method *o);
@@ -278,14 +281,20 @@ int knh_methodn_isNew(Ctx *ctx, knh_methodn_t mn);
 int knh_Method_isConstructor(Ctx *ctx, Method *o);
 int knh_methodn_isOp(Ctx *ctx, knh_methodn_t mn);
 String* knh_Method_getName(Ctx *ctx, Method *o);
-String* knh_Method_getURN(Ctx *ctx, Method *o);
 int knh_Method_isWoven(Method *mtd);
 int knh_Method_canWeave(Ctx *ctx, Method *mtd, Method *aspect);
 void knh_Method_weave(Ctx *ctx, Method *aspect, Method *mtd);
+void knh_Class_addMethod(Ctx *ctx, knh_class_t cid, Method *mtd);
+void konoha_addMethodFieldTable(Ctx *ctx, MethodField *mf);
+MethodField *konoha_findMethodField0(Ctx *ctx, knh_type_t rtype);
+MethodField *konoha_findMethodField1(Ctx *ctx, knh_type_t rtype, knh_type_t p1, knh_fieldn_t fn1);
+Method* knh_Class_getMethod__(Ctx *ctx, knh_class_t this_cid, knh_methodn_t mn, knh_bool_t gen);
+Method *konoha_lookupMethod(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
+Method *konoha_lookupFormatter(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
 /* ../src/class/knh_NameSpace.c */
 NameSpace* new_NameSpace(Ctx *ctx, NameSpace *parent, String *nsname);
-void knh_NameSpace_setClass(Ctx *ctx, NameSpace *o, String *name, knh_class_t c);
-knh_class_t knh_NameSpace_getClass(Ctx *ctx, NameSpace *o, knh_bytes_t name);
+void knh_NameSpace_seClassTable(Ctx *ctx, NameSpace *o, String *name, knh_class_t c);
+knh_class_t knh_NameSpace_geClassTable(Ctx *ctx, NameSpace *o, knh_bytes_t name);
 void knh_NameSpace_setLocalName(Ctx *ctx, NameSpace *o, knh_class_t cid);
 char* knh_Context_CLASSN(Ctx *ctx, knh_class_t cid);
 void knh_NameSpace_import(Ctx *ctx, NameSpace *o, knh_bytes_t p);
@@ -299,14 +308,17 @@ knh_bool_t knh_NameSpace_existsConst(Ctx *ctx, NameSpace *o, knh_bytes_t name);
 void knh_NameSpace_addConst(Ctx *ctx, NameSpace *o, String *name, Object *value);
 Object* knh_NameSpace_getConst(Ctx *ctx, NameSpace *o, knh_bytes_t name);
 /* ../src/class/knh_Number.c */
-knh_integer_t knh_Number_tointeger(Any *o);
+knh_int_t knh_Number_tointeger(Any *o);
 knh_float_t knh_Number_tofloat(Any *o);
 /* ../src/class/knh_Object.c */
 Object *new_Nue(Ctx *ctx, String *msg);
 METHOD knh__Object_new(Ctx *ctx, knh_sfp_t *sfp);
+String *knh_Object_getkey(Ctx *ctx, Object *o);
+METHOD knh__Object_getKey(Ctx *ctx, knh_sfp_t *sfp);
 Object *knh_Object_copy(Ctx *ctx, Object *b);
 knh_hcode_t knh_Object_hashCode(Ctx *ctx, Object *o);
 int knh_Object_compareTo(Ctx *ctx, Object *o1, Object *o2);
+int knh_Object_cmp(Object *o1, Object *o2);
 knh_bool_t knh_Object_equals(Ctx *ctx, Object *o1, Object *o2);
 knh_bytes_t knh_Object_tobytes(Ctx *ctx, Object *o);
 /* ../src/class/knh_OutputStream.c */
@@ -324,9 +336,9 @@ void knh_OutputStream_print_(Ctx *ctx, OutputStream *o, knh_bytes_t str, knh_boo
 /* ../src/class/knh_OutputStream_write.c */
 void knh_write__s(Ctx *ctx, OutputStream *w, char *s);
 void knh_write__p(Ctx *ctx, OutputStream *w, void *ptr);
-void knh_write__ifmt(Ctx *ctx, OutputStream *w, char *fmt, knh_int_t n);
+void knh_write__ifmt(Ctx *ctx, OutputStream *w, char *fmt, knh_intptr_t n);
 void knh_write__ffmt(Ctx *ctx, OutputStream *w, char *fmt, knh_float_t n);
-void knh_write_integerfmt(Ctx *ctx, OutputStream *w, char *fmt, knh_integer_t n);
+void knh_write_integerfmt(Ctx *ctx, OutputStream *w, char *fmt, knh_int_t n);
 void knh_write__flag(Ctx *ctx, OutputStream *w, knh_flag_t flag);
 void knh_write_cid(Ctx *ctx, OutputStream *w, knh_class_t cid);
 void knh_write_mn(Ctx *ctx, OutputStream *w, knh_methodn_t mn);
@@ -349,11 +361,11 @@ ResultSet* new_ResultSet(Ctx *ctx);
 knh_boolean_t knh_ResultSet_next(Ctx *ctx, ResultSet *o);
 METHOD knh__ResultSet_next(Ctx *ctx, knh_sfp_t *sfp);
 void knh_ResultSet_close(Ctx *ctx, ResultSet *o);
-void knh_ResultSet_initTargetClass(ResultSet *o, knh_class_t tcid);
+void knh_ResultSet_initTargeClassTable(ResultSet *o, knh_class_t tcid);
 String *knh_ResultSet_getName(Ctx *ctx, ResultSet *o, size_t n);
 int knh_ResultSet_findColumn(Ctx *ctx, ResultSet *o, knh_bytes_t name);
 knh_type_t knh_ResultSet_get_type(Ctx *ctx, ResultSet *o, size_t n);
-knh_integer_t knh_ResultSet_getInt(Ctx *ctx, ResultSet *o, size_t n);
+knh_int_t knh_ResultSet_getInt(Ctx *ctx, ResultSet *o, size_t n);
 knh_float_t knh_ResultSet_getFloat(Ctx *ctx, ResultSet *o, size_t n);
 String* knh_ResultSet_getString(Ctx *ctx, ResultSet *o, size_t n);
 /* ../src/class/knh_Runtime.c */
@@ -364,13 +376,13 @@ Script *knh_NameSpace_getScript(Ctx *ctx, NameSpace *ns);
 void knh_Script__k(Ctx *ctx, Script *o, OutputStream *w, String *m);
 void knh_Script__dump(Ctx *ctx, Script *o, OutputStream *w, String *m);
 /* ../src/class/knh_String.c */
-knh_hcode_t knh_string_hash(knh_uchar_t *buf, knh_size_t len);
+knh_hcode_t knh_string_hash(knh_uchar_t *buf, size_t len);
 void knh_String_checkASCII(String *o);
 knh_String_t *new_StringX__T(Ctx *ctx, knh_class_t cid, char *text);
 String *new_StringX__fast(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign);
 String *new_StringX__FormatException(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign);
 String *new_StringX(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign);
-String *new_String__integer(Ctx *ctx, knh_integer_t n);
+String *new_String__integer(Ctx *ctx, knh_int_t n);
 String *new_String__float(Ctx *ctx, knh_float_t n);
 char *knh_StringNULL_tochar(String *o);
 knh_bool_t knh_String_equals(String *o, knh_bytes_t s);
@@ -533,7 +545,7 @@ char * knh_format_homepath(char *buf, size_t bufsiz);
 int knh_isfile(Ctx *ctx, knh_bytes_t path);
 int knh_isdir(Ctx *ctx, knh_bytes_t path);
 int knh_isnewerfile(Ctx *ctx, char *path, char *path2);
-knh_uinteger_t knh_initseed();
+knh_uint_t knh_initseed();
 knh_uint64_t knh_timecount();
 /* ../src/deps/tbmx1.c */
 void *knh_dlopen(Ctx *ctx, const char* path, int mode);
@@ -542,6 +554,8 @@ const char *knh_dlerror(Ctx *ctx);
 int knh_dlclose(Ctx *ctx, void* handle);
 char * knh_format_homepath(char *buf, size_t bufsiz);
 /* ../src/deps/thread.c */
+knh_thread_t knh_thread_self();
+int thread_create(knh_thread_t *thread, void *attr, void *(*start_routine)(void *), void * arg);
 int knh_thread_key_create(knh_thread_key_t *key);
 int knh_thread_setspecific(knh_thread_key_t key, const void *data);
 void* knh_thread_getspecific(knh_thread_key_t key);
@@ -554,11 +568,11 @@ int knh_dlclose(Ctx *ctx, void* handle);
 char * knh_format_homepath(char *buf, size_t bufsiz);
 int knh_isfile(Ctx *ctx, knh_bytes_t path);
 int knh_isdir(Ctx *ctx, knh_bytes_t path);
-knh_uinteger_t knh_initseed();
+knh_uint_t knh_initseed();
 knh_uint64_t knh_timecount();
 /* ../src/konoha.c */
 int main(int argc, char **argv);
-/* ../src/main/b4.c */
+/* ../src/labs/b4.c */
 void konoha_initfibo(Ctx *ctx);
 METHOD knh__Script_fibo(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_changeChannel(Ctx *ctx, knh_sfp_t *sfp);
@@ -575,16 +589,6 @@ MAPPER knh_Mapper_fInterface(Ctx *ctx, knh_sfp_t *sfp);
 MAPPER knh_fmapper_null(Ctx *ctx, knh_sfp_t *sfp);
 knh_bool_t knh_Mapper_isNoSuchMapping(Mapper *mpr);
 Mapper *knh_tMapper_find_(Ctx *ctx, knh_class_t scid, knh_class_t tcid, int isgen);
-/* ../src/main/knh_tMethod.c */
-void knh_Class_addMethod(Ctx *ctx, knh_class_t cid, Method *mtd);
-void knh_tMethodField_add(Ctx *ctx, MethodField *mf);
-void knh_tMethodField_add0(Ctx *ctx, knh_flag_t flag, knh_type_t rtype);
-void knh_tMethodField_add1(Ctx *ctx, knh_flag_t flag, knh_type_t rtype, knh_type_t t1, knh_fieldn_t fn1);
-MethodField *knh_tMethodField(Ctx *ctx, size_t n);
-MethodField *knh_tMethodField_find0(Ctx *ctx, knh_type_t rtype);
-Method* knh_Class_getMethod__(Ctx *ctx, knh_class_t this_cid, knh_methodn_t mn, knh_bool_t gen);
-Method *knh_Method_ufind(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
-Method *knh_tMethod_findMT(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
 /* ../src/main/konoha_api.c */
 void konoha_init(void);
 METHOD knh__Script_eval(Ctx *ctx, knh_sfp_t *sfp);
@@ -592,15 +596,16 @@ METHOD knh__Script_isStatement(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_readLine(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_addHistory(Ctx *ctx, knh_sfp_t *sfp);
 /* ../src/main/konoha_data.c */
+knh_hcode_t knh_MethodField_hachCode(Ctx *ctx, MethodField *o);
 size_t f_bconv__NOP(Ctx *ctx, BytesConv *bc, knh_bytes_t t, knh_Bytes_t *ba);
 void knh_OutputStream_init(Ctx *ctx, OutputStream *out, int init);
 void knh_ExceptionHandler_traverse(Ctx *ctx, ExceptionHandler *hdr, knh_ftraverse gc);
 void knh_Context_init(Ctx *ctx, knh_Context_t *o, int init);
 void knh_Stmt_done(Ctx *ctx, Stmt *o);
 /* ../src/main/konoha_ext.c */
-void knh_srand(knh_uinteger_t seed);
+void knh_srand(knh_uint_t seed);
 METHOD knh__System_setRandomSeed(Ctx *ctx, knh_sfp_t *sfp);
-knh_uinteger_t knh_rand();
+knh_uint_t knh_rand();
 knh_float_t knh_float_rand();
 /* ../src/main/konoha_file.c */
 char * knh_format_parentpath(char *buf, size_t bufsiz, knh_bytes_t path, int n);
@@ -619,7 +624,7 @@ void *knh_malloc(Ctx *ctx, size_t size);
 void knh_free(Ctx *ctx, void *block, size_t size);
 void *DBG2_malloc(Ctx *ctx, size_t size, char *func);
 void DBG2_free(Ctx *ctx, void *p, size_t size, char *func);
-int konoha_RCcollect(Ctx *ctx);
+int knh_isFastMallocMemory(void *p);
 void *knh_fastmalloc(Ctx *ctx, size_t size);
 void knh_fastfree(Ctx *ctx, void *block, size_t size);
 knh_Object_t *new_hObject(Ctx *ctx, knh_flag_t flag, knh_class_t bcid, knh_class_t cid);
@@ -627,12 +632,10 @@ knh_Object_t *new_Object_bcid(Ctx *ctx, knh_class_t bcid, int init);
 knh_Object_t *new_Object_init(Ctx *ctx, knh_flag_t flag, knh_class_t cid, int init);
 void knh_Object_free(Ctx *ctx, knh_Object_t *o);
 void knh_Object_traverse(Ctx *ctx, knh_Object_t *o, knh_ftraverse ftr);
-void knh_fgchook_nop(Ctx *ctx);
-void knh_fgchook_collect(Ctx *ctx);
-void knh_Object_mark0(Ctx *ctx, Object *o);
+void knh_Object_mark1(Ctx *ctx, Object *o);
 METHOD knh__System_gc(Ctx *ctx, knh_sfp_t *sfp);
 void knh_Object_RCsweep(Ctx *ctx, Object *o);
-knh_ftraverse konoha_getDefaultSweepFunction();
+knh_ftraverse konoha_getDefaultSweepFunc();
 /* ../src/main/stack.c */
 int knh_sfp_argc(Ctx *ctx, knh_sfp_t *varg);
 char * knh_format_mtdparam(Ctx *ctx, char *buf, size_t bufsiz, Method *mtd, int n); void knh_sfp_typecheck(Ctx *ctx, knh_sfp_t *sfp, Method *mtd, knh_code_t *pc);
@@ -658,9 +661,8 @@ void konoha_addDriverAPI(Ctx *ctx, char *alias, knh_drvapi_t* p);
 knh_drvapi_t *konoha_getDriverAPI(Ctx *ctx, int type, knh_bytes_t name);
 NameSpace *knh_System_loadPackage(Ctx *ctx, knh_bytes_t pkgname);
 NameSpace *knh_System_getNameSpace(Ctx *ctx, knh_bytes_t name);
-ClassSpec *konoha_getClassSpec(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn);
+ClassSpec *konoha_geClassTableSpec(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn);
 /* ../src/main/systemtable.c */
-void konoha_initContext(Ctx *ctx, knh_Context_t *o, size_t stacksize);
 void knh_Context_traverse(Ctx *ctx, knh_Context_t *o, knh_ftraverse ftr);
 void konoha_traverse(Ctx* ctx, knh_ftraverse ftr);
 /* ../src/main/typesystem.c */
