@@ -39,7 +39,7 @@
 #else
 #define KONOHA_NAME     "konoha"
 #define KONOHA_MAJOR_VERSION "0.3"
-#define KONOHA_VERSION  "0.3.5"
+#define KONOHA_VERSION  "0.3.6"
 #endif
 
 #define KONOHA_URL		"http://konoha.sourceforge.jp/"
@@ -190,6 +190,12 @@
 
 /* ======================================================================== */
 
+#define KNH_SECUREMODE 1
+
+#define SECURE_bzero(o, s)  knh_bzero(o, s)
+
+/* ======================================================================== */
+
 #ifndef L1_CACHE_BYTES
 #define L1_CACHE_BYTES   32
 #endif
