@@ -33,6 +33,11 @@
 #include<float.h>
 #include<setjmp.h>
 
+#define __STDC_LIMIT_MACROS
+#include<stdint.h>
+#define __STDC_FORMAT_MACROS
+#include<inttypes.h>
+
 #include"konoha_config.h"
 
 #if defined(KNH_USING_PTHREAD)
@@ -45,13 +50,6 @@ extern "C" {
 
 /* ------------------------------------------------------------------------ */
 
-#ifndef INLINE
-#define INLINE             /*__inline__*/
-#endif
-
-#define PUBLIC
-#define PRIVATE            static
-
 #define METHOD             void  KNH_CC_FASTCALL
 #define MAPPER             METHOD
 #define ITRNEXT            METHOD
@@ -62,6 +60,8 @@ extern "C" {
 #define KNH_MT_VOLATILE
 #endif
 
+#define KONOHA_SYSTEM_BIT        (sizeof(void*) * CHAR_BIT))
+
 /* ------------------------------------------------------------------------ */
 /* Bool(ean), knh_bool_t */
 /* ------------------------------------------------------------------------ */
@@ -73,32 +73,161 @@ typedef int                      knh_boolean_t;
 /* Int, knh_int_t */
 /* ------------------------------------------------------------------------ */
 
-typedef signed long int           knh_int_t;    /* sizeof(knh_int_t) = sizeof(*p) */
-#define KNH_INT_MAX               LONG_MAX
-#define KNH_INT_MIN               LONG_MIN
-#define KNH_INT_FMT               "%ld"
-#define KNH_INT_FMTX              "%lx"
-#define KNH_INT_BSIZE             (sizeof(knh_int_t))
-#define KNH_INT_FMTSIZ            40
+typedef int16_t           knh_int16_t;
+typedef uint16_t          knh_uint16_t;
+typedef int16_t           knh_short_t;
+typedef uint16_t          knh_ushort_t;
+typedef int32_t           knh_int32_t;
+typedef uint32_t          knh_uint32_t;
+typedef int64_t           knh_int64_t;
+typedef uint64_t          knh_uint64_t;
 
-typedef unsigned long int         knh_uint_t;   /* sizeof(knh_uint_t) = sizeof(*p) */
+typedef intptr_t                  knh_intptr_t;
+typedef uintptr_t                 knh_uintptr_t;
+typedef knh_intptr_t              knh_index_t;
+
+#define KNH_INTPTR_FMT               "%"PRIdPTR
+
+//OLD
+//#define KNH_INTPTR_FMTX              "%"PRIxPTR
+//#define KNH_INT_BSIZE             (sizeof(knh_int_t))
+//#define KNH_UINT_FMT              "%lu"
+//typedef size_t                    knh_size_t;
+//typedef size_t                    bsize_t;
+//typedef knh_intptr_t                 int_byte_t;
+//#define KNH_INTPTR_MAX               LONG_MAX
+//#define KNH_INTPTR_MIN               LONG_MIN
+//#define KNH_UINTPTR_MAX              ULONG_MAX
+//#define KNH_UINTPTR_MIN              0
+
+/* ------------------------------------------------------------------------ */
+/* Integer, knh_int_t */
+/* ------------------------------------------------------------------------ */
+
+#ifdef KNH_USING_INT32
+
+typedef int32_t        knh_int_t;
+typedef uint32_t       knh_uint_t;
+
+#define KNH_INT_MAX               LONG_MAX
+#define KNH_INT_MIN               (LONG_MIN + 1)
+#define KNH_INT_NULL              (LONG_MIN)
+#define KNH_INT_FMT               "%ld"
+#define KNH_INT_XFMT              "%lx"
 #define KNH_UINT_MAX              ULONG_MAX
 #define KNH_UINT_MIN              0
 #define KNH_UINT_FMT              "%lu"
+#define knh_abs(n)                labs(n)
 
-typedef knh_int_t                 knh_index_t;
-typedef size_t                    knh_size_t;
-typedef size_t                    bsize_t;
-typedef knh_int_t                 int_byte_t;
+#else /*KNH_USING_INT32*/
 
-#define KONOHA_SYSTEM_BIT        (sizeof(knh_int_t) * CHAR_BIT))
+typedef knh_int64_t        knh_int_t;
+typedef knh_uint64_t       knh_uint_t;
+
+#ifndef LLONG_MIN
+#define LLONG_MIN -9223372036854775807LL
+#define LLONG_MAX  9223372036854775807LL
+#endif
+
+#ifndef ULLONG_MAX
+#define ULLONG_MAX 18446744073709551615ULL
+#endif
+
+#define KNH_INT_MAX               LLONG_MAX
+#define KNH_INT_MIN               (LLONG_MIN + 1)
+#define KNH_INT_NULL              (LLONG_MIN)
+#define KNH_INT_FMT               "%lld"
+#define KNH_INT_XFMT              "%llx"
+#define KNH_UINT_MAX              ULLONG_MAX
+#define KNH_UINT_MIN              0
+#define KNH_UINT_FMT              "%llu"
+#define knh_abs(n)                llabs(n)
+
+#endif/*KNH_USING_INT32*/
+
+#define KNH_INT_FMTSIZ            40
+
+//OLD
+//#define KNH_INT_BSIZE             (sizeof(knh_int_t))
 
 /* ------------------------------------------------------------------------ */
-/* knh_flag_t */
+/* Float, knh_float_t */
 /* ------------------------------------------------------------------------ */
 
-typedef short                     knh_short_t;
-typedef unsigned short            knh_ushort_t;
+#ifdef KNH_USING_LONGDOUBLE
+typedef long double               knh_float_t;
+#define KNH_FLOAT_MAX             LDBL_MAX
+#define KNH_FLOAT_MIN             (-(LDBL_MAX))
+#define KNH_FLOAT_STEP            LDBL_MIN
+#define KNH_FLOAT_FMT             "%Lf"
+#define KNH_FLOAT_FMT1            "%.1Lf"
+#define KNH_FLOAT_FMT2            "%.2Lf"
+#define KNH_FLOAT_FMT3            "%.3Lf"
+#define KNH_FLOAT_FMT4            "%.4Lf"
+#define KNH_FLOAT_FMTE            "%Le"
+#else/*KNH_USING_LONGDOUBLE*/
+
+#ifdef KNH_USING_FLOAT
+typedef float                     knh_float_t;
+#define KNH_FLOAT_MAX             FLT_MAX
+#define KNH_FLOAT_MIN             (-(FLT_MAX))
+#define KNH_FLOAT_STEP            FLT_MIN
+#define KNH_FLOAT_FMT             "%f"
+#define KNH_FLOAT_FMT1            "%.1f"
+#define KNH_FLOAT_FMT2            "%.2f"
+#define KNH_FLOAT_FMT3            "%.3f"
+#define KNH_FLOAT_FMT4            "%.4f"
+#define KNH_FLOAT_FMTE            "%e"
+#else/*KNH_USING_FLOAT*/
+
+typedef double                    knh_float_t;
+#define KNH_FLOAT_MAX             DBL_MAX
+#define KNH_FLOAT_MIN             (-(DBL_MAX))
+#define KNH_FLOAT_STEP            DBL_MIN
+#define KNH_FLOAT_FMT             "%f"
+#define KNH_FLOAT_FMT1            "%.1f"
+#define KNH_FLOAT_FMT2            "%.2f"
+#define KNH_FLOAT_FMT3            "%.3f"
+#define KNH_FLOAT_FMT4            "%.4f"
+#define KNH_FLOAT_FMTE            "%e"
+#endif/*KNH_USING_FLOAT*/
+#endif/*KNH_USING_LONGDOUBLE*/
+
+#define KNH_FLOAT_NAN             (0.0/0.0)
+#define KNH_FLOAT_NULL            KNH_FLOAT_NAN
+#define KNH_FLOAT_FMTSIZ          80
+
+/* ------------------------------------------------------------------------ */
+/* String, knh_uchar_t */
+/* ------------------------------------------------------------------------ */
+
+typedef unsigned char           knh_uchar_t;    /* byte */
+
+typedef struct {
+	knh_uchar_t *buf;
+	size_t     len;
+} knh_bytes_t;
+
+#define ismulti(c)             (((knh_uchar_t)c)>127)
+
+/* ------------------------------------------------------------------------ */
+/* ConstData  */
+/* ------------------------------------------------------------------------ */
+
+typedef struct {
+	char *name;
+	knh_int_t ivalue;
+} knh_IntConstData_t;
+
+typedef struct {
+	char *name;
+	knh_float_t fvalue;
+} knh_FloatConstData_t;
+
+typedef struct {
+	char *name;
+	char *value;
+} knh_StringConstData_t;
 
 /* ------------------------------------------------------------------------ */
 /* knh_flag_t */
@@ -123,197 +252,42 @@ typedef knh_ushort_t              knh_flag_t;    /* flag field */
 #define KNH_FLAG_T14    ((knh_flag_t)(1 << 1))
 #define KNH_FLAG_T15    ((knh_flag_t)(1 << 0))
 
-#define KNH_FLAG15    ((knh_flag_t)(1 << 15))
-#define KNH_FLAG14    ((knh_flag_t)(1 << 14))
-#define KNH_FLAG13    ((knh_flag_t)(1 << 13))
-#define KNH_FLAG12    ((knh_flag_t)(1 << 12))
-#define KNH_FLAG11    ((knh_flag_t)(1 << 11))
-#define KNH_FLAG10    ((knh_flag_t)(1 << 10))
-#define KNH_FLAG09     ((knh_flag_t)(1 << 9))
-#define KNH_FLAG08     ((knh_flag_t)(1 << 8))
-#define KNH_FLAG07     ((knh_flag_t)(1 << 7))
-#define KNH_FLAG06     ((knh_flag_t)(1 << 6))
-#define KNH_FLAG05     ((knh_flag_t)(1 << 5))
-#define KNH_FLAG04     ((knh_flag_t)(1 << 4))
-#define KNH_FLAG03     ((knh_flag_t)(1 << 3))
-#define KNH_FLAG02     ((knh_flag_t)(1 << 2))
-#define KNH_FLAG01     ((knh_flag_t)(1 << 1))
-#define KNH_FLAG00     ((knh_flag_t)(1 << 0))
-
-#define KNH_FLAG9      ((knh_flag_t)(1 << 9))
-#define KNH_FLAG8      ((knh_flag_t)(1 << 8))
-#define KNH_FLAG7      ((knh_flag_t)(1 << 7))
-#define KNH_FLAG6      ((knh_flag_t)(1 << 6))
-#define KNH_FLAG5      ((knh_flag_t)(1 << 5))
-#define KNH_FLAG4      ((knh_flag_t)(1 << 4))
-#define KNH_FLAG3      ((knh_flag_t)(1 << 3))
-#define KNH_FLAG2      ((knh_flag_t)(1 << 2))
-#define KNH_FLAG1      ((knh_flag_t)(1 << 1))
-#define KNH_FLAG0      ((knh_flag_t)(1 << 0))
-
 #define KNH_FLAG_SET(f,op)     (f) = ((f)|(op))
 #define KNH_FLAG_UNSET(f,op)   (f) = ((f)&(~(op)))
 #define KNH_FLAG_IS(f,op)      (((f) & (op)) == (op))
 
-/* ------------------------------------------------------------------------ */
-/* Float, knh_float_t */
-/* ------------------------------------------------------------------------ */
-
-#ifdef KNH_FLOAT_TYPE__LONG_DOUBLE
-	typedef long double               knh_float_t;
-	#define KNH_FLOAT_MAX             LDBL_MAX
-	#define KNH_FLOAT_MIN             (-(LDBL_MAX))
-	#define KNH_FLOAT_STEP            LDBL_MIN
-	#define KNH_FLOAT_FMT             "%Lf"
-	#define KNH_FLOAT_FMT1            "%.1Lf"
-	#define KNH_FLOAT_FMT2            "%.2Lf"
-	#define KNH_FLOAT_FMT3            "%.3Lf"
-	#define KNH_FLOAT_FMT4            "%.4Lf"
-	#define KNH_FLOAT_FMTE            "%Le"
-#else
-	#ifdef KNH_FLOAT_TYPE__FLOAT
-		typedef float                     knh_float_t;
-		#define KNH_FLOAT_MAX             FLT_MAX
-		#define KNH_FLOAT_MIN             (-(FLT_MAX))
-		#define KNH_FLOAT_STEP            FLT_MIN
-		#define KNH_FLOAT_FMT             "%f"
-		#define KNH_FLOAT_FMT1            "%.1f"
-		#define KNH_FLOAT_FMT2            "%.2f"
-		#define KNH_FLOAT_FMT3            "%.3f"
-		#define KNH_FLOAT_FMT4            "%.4f"
-		#define KNH_FLOAT_FMTE            "%e"
-	#else
-		typedef double                    knh_float_t;
-		#define KNH_FLOAT_MAX             DBL_MAX
-		#define KNH_FLOAT_MIN             (-(DBL_MAX))
-		#define KNH_FLOAT_STEP            DBL_MIN
-		#define KNH_FLOAT_FMT             "%f"
-		#define KNH_FLOAT_FMT1            "%.1f"
-		#define KNH_FLOAT_FMT2            "%.2f"
-		#define KNH_FLOAT_FMT3            "%.3f"
-		#define KNH_FLOAT_FMT4            "%.4f"
-		#define KNH_FLOAT_FMTE            "%e"
-	#endif
-#endif
-
-#define KNH_FLOAT_NAN             (0.0/0.0)
-#define KNH_FLOAT_NULL            KNH_FLOAT_NAN
-
-#define knh_double_t                    knh_float_t /* just in case */
-#define KNH_FLOAT_FMTSIZ                256
-
-/* ------------------------------------------------------------------------ */
-/* Long, knh_int64_t */
-/* ------------------------------------------------------------------------ */
-
-#ifndef LLONG_MIN
-#define LLONG_MIN -9223372036854775807LL
-#define LLONG_MAX  9223372036854775807LL
-#endif
-
-#ifndef ULLONG_MAX
-#define ULLONG_MAX 18446744073709551615ULL
-#endif
-
-typedef signed long long int           knh_int64_t;
-typedef unsigned long long int         knh_uint64_t;
-
-#define KNH_LONG_MAX   LLONG_MAX
-#define KNH_LONG_MIN   LLONG_MIN
-#define KNH_ULONG_MAX  ULLONG_MAX
-#define KNH_ULONG_MIN  ((knh_uint64_t)0)
-
-/* ------------------------------------------------------------------------ */
-/* Integer, knh_integer_t */
-/* ------------------------------------------------------------------------ */
-
-#ifdef KNH_USING_INT32
-
-typedef knh_int_t        knh_integer_t;
-typedef knh_uint_t       knh_uinteger_t;
-
-#define KNH_INTEGER_MAX               LONG_MAX
-#define KNH_INTEGER_MIN               (LONG_MIN + 1)
-#define KNH_INTEGER_NULL              (LONG_MIN)
-#define KNH_INTEGER_FMT               "%ld"
-#define KNH_INTEGER_XFMT              "%lx"
-#define KNH_INTEGER_BSIZE             (sizeof(knh_integer_t))
-#define KNH_INTEGER_FMTSIZ            40
-#define KNH_UINTEGER_MAX              ULONG_MAX
-#define KNH_UINTEGER_MIN              0
-#define KNH_UINTEGER_FMT              "%lu"
-#define knh_abs(n)                labs(n)
-
-#else /*KNH_USING_INT32*/
-
-typedef knh_int64_t        knh_integer_t;
-typedef knh_uint64_t       knh_uinteger_t;
-
-#define KNH_INTEGER_MAX               LLONG_MAX
-#define KNH_INTEGER_MIN               (LLONG_MIN + 1)
-#define KNH_INTEGER_NULL              (LLONG_MIN)
-#define KNH_INTEGER_FMT               "%lld"
-#define KNH_INTEGER_XFMT              "%llx"
-#define KNH_INTEGER_BSIZE             (sizeof(knh_integer_t))
-#define KNH_INTEGER_FMTSIZ            40
-#define KNH_UINTEGER_MAX              ULLONG_MAX
-#define KNH_UINTEGER_MIN              0
-#define KNH_UINTEGER_FMT              "%llu"
-#define knh_abs(n)                llabs(n)
-
-#endif/*KNH_USING_INT32*/
-
-#define _DCAST(t,v)     ((t)v)
-
-/* ------------------------------------------------------------------------ */
-/* String, knh_uchar_t */
-/* ------------------------------------------------------------------------ */
-
-typedef unsigned char           knh_uchar_t;    /* byte */
-
-typedef struct {
-	knh_uchar_t *buf;
-	size_t     len;
-} knh_bytes_t;
-
-#define ismulti(c)             (((knh_uchar_t)c)>127)
-
-
-/* ------------------------------------------------------------------------ */
-/* ConstData  */
-/* ------------------------------------------------------------------------ */
-
-typedef struct {
-	char *name;
-	knh_integer_t ivalue;
-} knh_IntConstData_t;
-
-typedef struct {
-	char *name;
-	knh_float_t fvalue;
-} knh_FloatConstData_t;
-
-typedef struct {
-	char *name;
-	char *value;
-} knh_StringConstData_t;
-
 /* ------------------------------------------------------------------------ */
 /* Struct, Class, Type  */
 /* ------------------------------------------------------------------------ */
 
-typedef unsigned short       knh_struct_t ; /* struct id*/
-typedef unsigned short       knh_class_t;   /* class id */
-typedef unsigned short       knh_type_t;    /* extended knh_type_t */
-typedef unsigned short       knh_expt_t;    /* knh_expt_t */
+typedef const struct knh_Context_t    Ctx;
 
-#define KNH_CLASSSPEC_FMT    "%s{%s}"
+typedef knh_uint16_t       knh_struct_t ; /* struct id*/
+typedef knh_uint16_t       knh_class_t;   /* class id */
+typedef knh_uint16_t       knh_type_t;    /* extended knh_type_t */
+typedef knh_uint16_t       knh_expt_t;    /* knh_expt_t */
+
+#define KNH_FLAG_TF_NN                KNH_FLAG_T0
+#define TYPE_ISNULLABLE(t)            ((t & KNH_FLAG_TF_NN)==0)
+#define IS_NNTYPE(t)                  ((t & KNH_FLAG_TF_NN)==KNH_FLAG_TF_NN)
+#define NNTYPE_cid(c)                 (c|KNH_FLAG_TF_NN)
+#define TYPE_TONNTYPE(t)              (t|KNH_FLAG_TF_NN)
+
+#define CLASS_type(t)                (t&(~KNH_FLAG_TF_NN))
+
+// @NOUSE
+#define TYPEQN(t)                     TYPEN(t), TYPEQ(t)
+
+#define TYPE_void                     NNTYPE_cid(CLASS_Nue)
+#define NNTYPE_void                   NNTYPE_cid(CLASS_Nue)
+#define TYPE_any                      CLASS_Any
+#define NNTYPE_any                    CLASS_any
+
+//OLD
+//typedef knh_ushort_t          knh_nsid_t;
 
 /* ------------------------------------------------------------------------ */
 
-typedef knh_ushort_t          knh_nsid_t;
-typedef knh_ushort_t          knh_fileid_t;
-
 typedef knh_ushort_t          knh_fieldn_t;
 typedef knh_ushort_t          knh_methodn_t;
 
@@ -333,14 +307,6 @@ typedef knh_ushort_t          knh_methodn_t;
 
 #define FIELDN_UNMASK(fnq)         (fnq & (~(KNH_FLAG_FN_SUPER|KNH_FLAG_FN_U1|KNH_FLAG_FN_U2)))
 
-//#define _METHODN_NONAME   KONOHA_TCLASS_SIZE
-//#define _METHODN_NEWID    0
-
-// 0000 0000 0000 0000
-// 0100 0000 0000 0000
-// 0010 0000 0000 0000
-// 0110 0000 0000 0000
-
 #define KNH_FLAG_MN_SUPER        KNH_FLAG_T0
 #define KNH_FLAG_MN_GETTER       KNH_FLAG_T1
 #define KNH_FLAG_MN_SETTER       KNH_FLAG_T2
@@ -356,42 +322,19 @@ typedef knh_ushort_t          knh_methodn_t;
 
 #define METHODN_TOFIELDN(mn)     (mn & KNH_FLAG_MN_FIELDN)
 
+/* ------------------------------------------------------------------------ */
+
 /* ------------------------------------------------------------------------ */
 /* Object */
 /* ------------------------------------------------------------------------ */
 
 #define KNH_OBJECT_MAGIC         578
-#define KNH_FASTMALLOC_MAGIC     911
 
 #ifdef KNH_USING_RCGC
 #define KNH_HOBJECT_REFC      1
 #endif
 
-typedef struct knh_hObject_t {
-	knh_ushort_t magic;
-	knh_flag_t  flag;
-	knh_class_t bcid;
-	knh_class_t cid;
-#ifdef KNH_HOBJECT_REFC
-	KNH_MT_VOLATILE knh_uint_t refc;
-#endif
-} knh_hObject_t ;
-
-typedef struct knh_fObject_t {
-	void *meta;
-	struct knh_Object_t *recentCreatedObject;
-} knh_fObject_t ;
-
-#define SIZEOF_FOBJECT_T  sizeof(knh_fObject_t)
-
-typedef struct knh_Object_t {
-	knh_hObject_t h;
-	void *ref;
-	void *ref2_unused;
-	void *ref3_unused;
-	knh_fObject_t f;
-} knh_Object_t ;
-
+typedef knh_ushort_t knh_lock_t;
 
 #ifdef KNH_OBJECT_MAGIC
 	#define KNH_ASSERT_ISOBJECT(o)        DBG2_ASSERT((o)->h.magic == KNH_OBJECT_MAGIC)
@@ -399,6 +342,23 @@ typedef struct knh_Object_t {
 	#define KNH_ASSERT_ISOBJECT(o)
 #endif/*KONOHA_OBJECT_MAGIC*/
 
+typedef struct knh_hObject_t {
+	knh_ushort_t magic; knh_flag_t  flag;
+	knh_class_t bcid;   knh_class_t cid;
+	knh_ushort_t ctxid; knh_lock_t  lock;
+#ifdef KNH_HOBJECT_REFC
+	KNH_MT_VOLATILE knh_uintptr_t refc;
+#endif
+	void *meta;
+} knh_hObject_t ;
+
+typedef struct knh_Object_t {
+	knh_hObject_t h;
+	void *ref;
+	void *ref2_unused;
+	void *ref3_unused;
+} knh_Object_t ;
+
 /* types of basic objects (not type-checked) */
 
 #define Object          knh_Object_t
@@ -412,28 +372,79 @@ typedef struct knh_Object_t {
 #define KNH_FIELDn(v,n)            ((Script*)(v))->fields[(n)]
 
 /* ------------------------------------------------------------------------ */
-/* Context */
+/* Common Object Structure */
+
+typedef knh_ushort_t          knh_fileid_t;
+typedef knh_ushort_t          knh_sline_t;
+
+typedef struct {
+	knh_hObject_t h;
+	void *ref;
+	knh_fileid_t fileid;
+	knh_sline_t  line;
+} knh_FileLine_t ;
+
+/* ------------------------------------------------------------------------ */
+/* Thread */
+/* ------------------------------------------------------------------------ */
+
+#define KNH_USING_NOTHREAD 1
+#ifdef KNH_USING_PTHREAD
+#undef KNH_USING_NOTHREAD
+typedef pthread_t knh_thread_t;
+typedef pthread_key_t knh_thread_key_t;
+typedef pthread_mutex_t  knh_mutex_t;
+#endif
+
+#ifdef KNH_USING_NOTHREAD
+typedef knh_int_t knh_thread_t;
+typedef knh_int_t knh_thread_key_t;
+typedef knh_int_t knh_mutex_t;
+#endif
+
+typedef struct knh_Thread_t {
+	knh_hObject_t h;
+	knh_thread_t thid;
+} knh_Thread_t ;
+
+
+#ifndef KNH_TLOCK_SIZE
+#define KNH_TLOCK_SIZE 256
+#endif
+
+#define SIZEOF_TLOCK       (KNH_TLOCK_SIZE * sizeof(knh_LockTable_t))
+
+typedef void (*knh_fmutexlock)(Ctx *ctx, knh_lock_t lock, Object *o);
+typedef void (*knh_fmutexunlock)(Ctx *ctx, knh_lock_t lock);
+
+typedef struct knh_LockTable_t {
+	knh_lock_t  lock;     knh_flag_t  flag;
+	knh_mutex_t mutex;
+	knh_fmutexlock       flock;
+	knh_fmutexunlock       funlock;
+	int ctxid;
+	size_t count;
+	struct knh_String_t *name;
+	union {
+		Object *sharedObject;
+		struct knh_LockTable_t *unused;
+	};
+} knh_LockTable_t;
+
+#define LOCK_NO           ((knh_lock_t)0)
+#define LOCK_MEMORY       ((knh_lock_t)1)
+#define LOCK_SYSTBL       ((knh_lock_t)2)
+#define LOCK_GIANT        ((knh_lock_t)3)
+
+#define KNH_LOCK(ctx, lk, o)    (ctx->share)->LockTable[lk].flock(ctx, lk, o)
+#define KNH_UNLOCK(ctx, lk, o)  (ctx->share)->LockTable[lk].funlock(ctx, lk)
+
+/* ------------------------------------------------------------------------ */
+/* Stack Frame Pointer */
 /* ------------------------------------------------------------------------ */
 
 typedef unsigned char           knh_code_t;          /* knh_vmc_t */
 
-#define p_size(a)      ((size_t)(a).ivalue)
-#define p_int(a)         ((knh_int_t)(a).ivalue)
-#define p_uint(a)        ((knh_uint_t)(a).ivalue)
-#define p_integer(a)     ((a).ivalue)
-#define p_uinteger(a)    ((knh_uinteger_t)(a).ivalue)
-
-#define p_float(a)       ((a).fvalue)
-#define p_double(a)      ((double)(a).fvalue)
-#define p_bool(a)        ((a).bvalue)
-#define p_char(a)        (knh_String_tochar(a.s))
-#define p_bytes(a)       (knh_Bytes_tobytes(a.s))
-#define p_cid(a)         ((a.c)->cid)
-#define ARG_Object_cid(a)  knh_Object_cid(a.o)
-#define p_cptr(a)        ((a.glue)->ptr)
-
-/* ------------------------------------------------------------------------ */
-
 typedef struct knh_sfp_t {
 	union {
 		void   *ref;
@@ -454,162 +465,56 @@ typedef struct knh_sfp_t {
 	};
 	union {
 		knh_boolean_t bvalue;
-		knh_integer_t ivalue;
+		knh_int_t     ivalue;
 		knh_float_t   fvalue;
-		knh_uint64_t   data;
-		knh_code_t       *pc;
+		knh_uint64_t  data;
+		knh_code_t    *pc;
 	};
 } knh_sfp_t;
 
-
-#define KNH_RETURN(ctx, sfp, v) {\
-		Int *n_ = (Int*)v;\
-		KNH_NGCMOV(ctx, sfp[-1].o, n_);\
-		sfp[-1].data = (n_)->n.data;\
-		return; \
-	}\
-
-#define KNH_RETURN_void(ctx, sfp)      {\
-		KNH_NGCMOV(ctx, sfp[-1].o, KNH_VOID); \
-		return; \
-	}\
-
-#define KNH_RETURN_Boolean(ctx, sfp, c) {\
-		sfp[-1].bvalue = c; \
-		return; \
-	}\
-
-#define KNH_RETURN_Int(ctx, sfp, n)      {\
-		sfp[-1].ivalue = (knh_integer_t)n;\
-		return; \
-	}\
-
-#define KNH_RETURN_NNInt(ctx, sfp, n)      {\
-		KNH_NGCMOV(ctx, sfp[-1].o, KNH_INT0);\
-		sfp[-1].ivalue = (knh_integer_t)n;\
-		return; \
-	}\
-
-#define KNH_RETURN_Float(ctx, sfp, n)      {\
-		sfp[-1].fvalue = (knh_float_t)n;\
-		return; \
-	}\
-
-#define KNH_RETURN_NNFloat(ctx, sfp, n)      {\
-		KNH_NGCMOV(ctx, sfp[-1].o, KNH_FLOAT0);\
-		sfp[-1].fvalue = (knh_float_t)n;\
-		return; \
-	}\
-
-#define KNH_ITRNEXT(ctx, sfp, i, v) {\
-		KNH_MOV(ctx, sfp[i].o, v);\
-		sfp[i].data = ((Int*)v)->n.data;\
-		return; \
-	}\
-
-#define KNH_ITREND(ctx, sfp, n) {\
-		knh_Iterator_close(ctx, sfp[0].it);\
-		KNH_MOV(ctx, sfp[n].o, KNH_VOID);\
-		return; \
-	}\
-
-#define HAS_ITRNEXT(v)   IS_NOTNULL(v)
-
-#define KNH_ITRNEXT_Int(ctx, sfp, n, value) {\
-		sfp[n].ivalue = value;\
-		KNH_MOV(ctx, sfp[n].o, KNH_INT0);\
-		return; \
-	}\
-
-#define KNH_ITRNEXT_Float(ctx, sfp, n, value) {\
-		sfp[n].fvalue = value;\
-		KNH_MOV(ctx, sfp[n].o, KNH_FLOAT0);\
-		return; \
-	}\
-
-#define KNH_MAPPED(ctx, sfp, v) {\
-		KNH_MOV(ctx, sfp[0].o, v);\
-		sfp[0].data = ((Int*)v)->n.data;\
-		return; \
-	}\
-
-#define KNH_MAPPED_Boolean(ctx, sfp, value) {\
-		sfp[0].bvalue = value;\
-		KNH_MOV(ctx, sfp[0].o, KNH_TRUE);\
-		return; \
-	}\
-
-#define KNH_MAPPED_Int(ctx, sfp, value) {\
-		sfp[0].ivalue = value;\
-		KNH_MOV(ctx, sfp[0].o, KNH_INT0);\
-		return; \
-	}\
-
-#define KNH_MAPPED_Float(ctx, sfp, value) {\
-		sfp[0].fvalue = value;\
-		KNH_MOV(ctx, sfp[0].o, KNH_FLOAT0);\
-		return;\
-	}\
-
 /* ------------------------------------------------------------------------ */
 /* [Context] */
 /* ------------------------------------------------------------------------ */
 
-typedef const struct knh_Context_t    Ctx;
-
-#define KNH_TOBJECT_SIZE     4096
-#define SIZEOF_TOBJECT       (sizeof(knh_Object_t) * KNH_TOBJECT_SIZE)
-
-#define KNH_FASTMALLOC_SIZE  (sizeof(knh_Object_t) - sizeof(void*))
+#define KNH_FASTMALLOC_SIZE  sizeof(knh_Object_t)
 #define KNH_FASTMALLOC_BSIZE (KNH_FASTMALLOC_SIZE/sizeof(knh_Object_t*))
-
 #define KNH_SMALLMALLOC_SIZE 80
 
 /* ------------------------------------------------------------------------ */
-/* [Thread] */
-/* ------------------------------------------------------------------------ */
-
-#define KNH_USING_NOTHREAD 1
-#ifdef KNH_USING_PTHREAD
-#undef KNH_USING_NOTHREAD
-#define knh_thread_key_t pthread_key_t
-#endif
-
-#ifdef KNH_USING_NOTHREAD
-#define knh_thread_key_t int
-#endif
-
-/* ------------------------------------------------------------------------ */
-
-#define STRUCT_newid         ((knh_struct_t)-1)
-
-#define SIZEOF_TSTRUCT    (KNH_TSTRUCT_SIZE * sizeof(knh_tStruct_t))
-
-char *konoha_getStructName(Ctx *ctx, knh_struct_t sid);
-#define STRUCTN(sid)   konoha_getStructName(ctx, sid)
+/* [StructTable] */
 
 #ifndef KNH_TSTRUCT_SIZE
 #define KNH_TSTRUCT_SIZE 256
 #endif
 
+#define STRUCT_newid         ((knh_struct_t)-1)
+#define SIZEOF_TSTRUCT       (KNH_TSTRUCT_SIZE * sizeof(knh_StructTable_t))
+
+char *konoha_geStructTableName(Ctx *ctx, knh_struct_t sid);
+#define STRUCTN(sid)         konoha_geStructTableName(ctx, sid)
+
 typedef void (*knh_fgchook)(Ctx *ctx);
 typedef void (*knh_ftraverse)(Ctx *ctx, Object *);
 typedef int (*knh_finit)(Ctx *);
 
-typedef knh_uint_t                knh_hcode_t;  /* knh_hcode_t */
+typedef knh_uintptr_t                knh_hcode_t;  /* knh_hcode_t */
 #define knh_hcode_join(s1,s2)	   ((knh_hcode_t)s1 << (sizeof(knh_short_t)*8)) + s2;
 
-typedef void        (*knh_fstruct_init)(Ctx *, Object *, int);
-typedef void        (*knh_fstruct_traverse)(Ctx *, Object*, knh_ftraverse);
-typedef int         (*knh_fstruct_compareTo)(Ctx *ctx, Object*, Object*);
-typedef knh_hcode_t (*knh_fstruct_hashCode)(Ctx *ctx, Object *);
-typedef Object*     (*knh_fstruct_copy)(Ctx *, Object *);
-typedef void        (*knh_fstruct_newClass)(Ctx *ctx, knh_class_t cid);
+#define KNH_OBJECT_RAWINIT              (-1)
+
+typedef void         (*knh_fstruct_init)(Ctx *, Object *, int);
+typedef void         (*knh_fstruct_traverse)(Ctx *, Object*, knh_ftraverse);
+typedef int          (*knh_fstruct_compareTo)(Object*, Object*);
+typedef knh_hcode_t  (*knh_fstruct_hashCode)(Ctx *ctx, Object *);
+typedef Object*      (*knh_fstruct_copy)(Ctx *, Object *);
+typedef void         (*knh_fstruct_newClass)(Ctx *ctx, knh_class_t cid);
+typedef struct knh_String_t* (*knh_fstruct_getkey)(Ctx *ctx, knh_sfp_t *lsfp);
 
 typedef struct {
 	knh_fstruct_traverse   ftraverse;
 	knh_fstruct_compareTo  fcompareTo;
 	knh_fstruct_init       finit;
+	knh_fstruct_getkey     fgetkey;
 	size_t                 size;
 	knh_flag_t             flag;
 	knh_struct_t           sid;
@@ -617,7 +522,7 @@ typedef struct {
 	knh_fstruct_copy       fcopy;
 	knh_fstruct_newClass   fnewClass;
 	char                  *name;
-} knh_tStruct_t ;
+} knh_StructTable_t ;
 
 /* ------------------------------------------------------------------------ */
 
@@ -625,7 +530,7 @@ typedef struct {
 #define KNH_TCLASS_SIZE 1024
 #endif
 
-#define SIZEOF_TCLASS  (KNH_TCLASS_SIZE * sizeof(knh_tClass_t))
+#define SIZEOF_TCLASS  (KNH_TCLASS_SIZE * sizeof(knh_ClassTable_t))
 
 typedef knh_Object_t* (*knh_fdefault)(Ctx *ctx, knh_class_t cid);
 
@@ -649,8 +554,11 @@ typedef struct {
 	struct knh_ClassStruct_t  *cstruct;
 	struct knh_ClassMap_t     *cmap;
 	struct knh_Object_t       *cspec;
-	knh_fdefault                  fdefault;
-} knh_tClass_t;
+	knh_fdefault               fdefault;
+	knh_mutex_t                dataLock;
+	struct knh_Array_t        *dataList;
+	struct knh_DictMap_t      *dataMap;
+} knh_ClassTable_t;
 
 /* ------------------------------------------------------------------------ */
 
@@ -658,15 +566,41 @@ typedef struct {
 #define KNH_TEXPT_SIZE (KNH_TCLASS_SIZE/4)
 #endif
 
+#define SIZEOF_TEXPT  (KNH_TEXPT_SIZE * sizeof(knh_ExptTable_t))
+
 typedef struct {
 	knh_flag_t   flag;
 	knh_expt_t   parent;
 	struct knh_String_t     *name;
-} knh_tExpt_t;
-
-#define SIZEOF_TEXPT  (KNH_TEXPT_SIZE * sizeof(knh_tExpt_t))
+} knh_ExptTable_t;
 
 /* ------------------------------------------------------------------------ */
+/* [SystemStat] */
+
+typedef struct {
+	size_t usedMemorySize;
+	size_t usedObjectSize;
+	size_t mtdCacheHit;
+	size_t mtdCacheMiss;
+	size_t fmtCacheHit;
+	size_t fmtCacheMiss;
+	size_t mprCacheHit;
+	size_t mprCacheMiss;
+} knh_ctxstat_t;
+
+#define knh_stat_incUsedMemorySize(ctx, n)   (ctx->stat)->usedMemorySize += (n)
+#define knh_stat_dclUsedMemorySize(ctx, n)   (ctx->stat)->usedMemorySize -= (n)
+#define knh_stat_incUsedObjectSize(ctx, n)   (ctx->stat)->usedObjectSize += (n)
+#define knh_stat_dclUsedObjectSize(ctx, n)   (ctx->stat)->usedObjectSize -= (n)
+#define knh_stat_mtdCacheHit(ctx)   (ctx->stat)->mtdCacheHit += 1
+#define knh_stat_mtdCacheMiss(ctx)  (ctx->stat)->mtdCacheMiss += 1
+#define knh_stat_fmtCacheHit(ctx)   (ctx->stat)->fmtCacheHit += 1
+#define knh_stat_fmtCacheMiss(ctx)  (ctx->stat)->fmtCacheMiss += 1
+#define knh_stat_mprCacheHit(ctx)   (ctx->stat)->mprCacheHit += 1
+#define knh_stat_mprCacheMiss(ctx)  (ctx->stat)->mprCacheMiss += 1
+
+/* ------------------------------------------------------------------------ */
+/* [SystemShare] */
 
 #ifndef KNH_TINT_MIN
 #define KNH_TINT_MIN (-1)  /* @property */
@@ -686,50 +620,59 @@ typedef struct {
 #define knh_rootNameSpace     DP(ctx->sys)->ns
 #define knh_systemEncoding    DP(ctx->sys)->enc
 
-#define KNH_NULL            (ctx->constNull)
-#define KNH_VOID            (ctx->constVoid)
-#define KNH_TRUE            (ctx->constTrue)
-#define KNH_FALSE           (ctx->constFalse)
+#define KNH_NULL            (ctx->share->constNull)
+#define KNH_VOID            (ctx->share->constVoid)
+#define KNH_TRUE            (ctx->share->constTrue)
+#define KNH_FALSE           (ctx->share->constFalse)
 #define KNH_SYSTEM          (ctx->sys)
-#define KNH_INT0            (ctx->tInt[0 - KNH_TINT_MIN])
-#define KNH_FLOAT0          (ctx->constFloat0)
+#define KNH_INT0            (ctx->share->tInt[0 - KNH_TINT_MIN])
+#define KNH_FLOAT0          (ctx->share->constFloat0)
 
 /* ------------------------------------------------------------------------ */
 
-typedef int knh_mutex_t;
-typedef int (*knh_fmutexlock)(knh_mutex_t*);
-typedef int (*knh_fmutexunlock)(knh_mutex_t*);
-
-#define KNH_LOCK(ctx, lock)    (ctx->share)->flock(lock);
-#define KNH_UNLOCK(ctx, lock)  (ctx->share)->funlock(lock);
-
 #define knh_Object_sweep       (ctx)->fsweep
 #define IS_SWEEP(f)            (f == knh_Object_sweep)
 
 /* ------------------------------------------------------------------------ */
 
-typedef struct knh_ContextShare_t {
-	size_t statUsedMemorySize;
-	size_t statUsedObjectSize;
-	size_t maxObjectTableSize;
-	size_t tObjectTableSize;
-	size_t tClassSize;
-	size_t maxContextSize;
-	size_t tContextSize;
-	knh_struct_t tStructSize; knh_expt_t   tExptSize;
-	/* 32bytes used until here*/
-	knh_fmutexlock        flock;
-	knh_fmutexunlock      funlock;
-	knh_mutex_t           objectLock;
-	knh_mutex_t           tableLock;
-} knh_ContextShare_t ;
+#ifndef KNH_TOBJECTPAGE_SIZE
+#define KNH_TOBJECTPAGE_SIZE     1024
+#endif
+
+#define SIZEOF_TOBJECTPAGE       (sizeof(knh_ObjectPageTable_t) * KNH_TOBJECTPAGE_SIZE)
+
+#ifndef KNH_OBJECTPAGE_SIZE
+#define KNH_OBJECTPAGE_SIZE     4096
+#endif
+
+#define SIZEOF_OBJECTPAGE       (sizeof(knh_Object_t) * KNH_OBJECTPAGE_SIZE)
+
+typedef struct knh_ObjectPageTable_t {
+	int   ctxid;
+	void *thead;
+} knh_ObjectPageTable_t ;
 
 /* ------------------------------------------------------------------------ */
 
-typedef struct knh_ObjectTable_t {
-	int    ctxid;
-	knh_Object_t *table;
-} knh_ObjectTable_t ;
+typedef struct {
+	/* system table */
+	size_t              threadSize;
+	knh_LockTable_t    *LockTable;
+	knh_LockTable_t    *unusedLockTable;
+	knh_ObjectPageTable_t  *ObjectPageTable; size_t ObjectPageTableSize;
+	knh_StructTable_t  *StructTable; size_t StructTableSize;
+	knh_ClassTable_t   *ClassTable;  size_t ClassTableSize;
+	knh_ExptTable_t    *ExptTable;   size_t ExptTableSize;
+
+	/* system const */
+	knh_Object_t   *constNull;
+	knh_Object_t   *constVoid;
+	knh_Object_t   *constTrue;
+	knh_Object_t   *constFalse;
+	struct knh_Float_t   *constFloat0;
+	struct knh_Int_t     **tInt;
+	struct knh_String_t  **tString;
+} knh_ctxshare_t ;
 
 /* ------------------------------------------------------------------------ */
 
@@ -737,42 +680,30 @@ typedef struct knh_Context_t {
 	knh_hObject_t h;
 	knh_Object_t        *unusedObject;
 	size_t               unusedObjectSize;
-	knh_Object_t        *recentCreatedObject;
-	size_t               recentCreatedObjectSize;
 
 	/* stack */
 	knh_sfp_t*                   stack;
 	knh_sfp_t*                   esp;
 	size_t                       stacksize;
+	knh_ftraverse                fsweep;
+
+	/* cache (stacksize * 2 + 1) */
+	size_t                        cachesize;
+	struct knh_Method_t         **mtdCache;
+	struct knh_Method_t         **fmtCache;
+	struct knh_Mapper_t         **mprCache;
 
 	/* root table */
-	struct knh_Context_t *tContext;
-	struct knh_ContextShare_t   *share;
-
-	/* system table */
-	knh_ObjectTable_t *tObjectTable;
-	knh_tStruct_t  *tStruct;
-	knh_tClass_t   *tClass;
-	knh_tExpt_t    *tExpt;
-	knh_ftraverse   fsweep;
-	knh_fgchook     fgchook;
-
-	/* system const */
-	knh_Object_t   *constNull;
-	knh_Object_t   *constVoid;
-	knh_Object_t   *constTrue;
-	knh_Object_t   *constFalse;
-	struct knh_Int_t     **tInt;
-	struct knh_Float_t    *constFloat0;
-	struct knh_String_t  **tString;
-	struct knh_System_t   *sys;
-
-	knh_mutex_t           *objectLock;
-	knh_mutex_t           *tableLock;
+	knh_ctxshare_t   *share;
+	knh_ctxstat_t    *stat;
 
 	knh_flag_t                   flag;
 	knh_ushort_t                 ctxid;
 	char*                        cwd;
+	knh_thread_t                 threadid;
+	struct knh_Context_t        *parent;
+
+	struct knh_System_t*         sys;
 	struct knh_String_t*         enc;
 	struct knh_InputStream_t*    in;
 	struct knh_OutputStream_t*   out;
@@ -781,13 +712,13 @@ typedef struct knh_Context_t {
 	struct knh_OutputStream_t*   bufw;
 	struct knh_Bytes_t*          bconvbuf;
 	struct knh_DictMap_t*        props;
-	struct knh_HashMap_t        *tmapperHashMap;
-	struct knh_HashMap_t        *tmethodHashMap;
+
 	struct knh_NameSpace_t      *ns;
 	struct knh_DictMap_t        *tsymbolDictMap;
 	struct knh_Asm_t            *cmpr;
-	struct knh_Context_t        *parent;
 
+//	struct knh_HashMap_t        *tmapperHashMap;
+//	struct knh_HashMap_t        *tmethodHashMap;
 } knh_Context_t ;
 
 /* ------------------------------------------------------------------------ */
@@ -795,7 +726,7 @@ typedef struct knh_Context_t {
 #define KONOHA_MAGIC        314159
 
 typedef struct konoha_t {
-	knh_uint_t  magic;
+	knh_uintptr_t  magic;
 	Ctx *ctx;
 } konoha_t ;
 
@@ -813,9 +744,6 @@ typedef struct konoha_t {
 		return value; \
 	}\
 
-//typedef knh_uint_t                int;
-//typedef knh_uint_t                knh_stackop_t;
-
 /* ------------------------------------------------------------------------ */
 /* KLRCode */
 /* ------------------------------------------------------------------------ */
@@ -842,9 +770,6 @@ typedef void   (KNH_CC_FASTCALL *knh_fmapper)(Ctx *, knh_sfp_t *);
 typedef MAPPER (*knh_fmapper)(Ctx *, knh_sfp_t *);
 #endif
 
-typedef knh_ushort_t             knh_sline_t;
-
-
 /* ======================================================================== */
 /* driver */
 /* ======================================================================== */
@@ -882,11 +807,11 @@ typedef struct {
 /* ------------------------------------------------------------------------ */
 /* KNH_DRVAPI_TYPE__IO */
 
-typedef knh_int_t knh_io_t;
+typedef knh_intptr_t knh_io_t;
 
 typedef knh_io_t (*f_io_open)(Ctx *ctx, struct knh_InputStream_t *in, struct knh_OutputStream_t *out, knh_bytes_t urn, char *mode);
-typedef knh_int_t (*f_io_read)(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz);
-typedef knh_int_t (*f_io_write)(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz);
+typedef knh_intptr_t (*f_io_read)(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz);
+typedef knh_intptr_t (*f_io_write)(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz);
 typedef void   (*f_io_close)(Ctx *ctx, knh_io_t fd);
 
 typedef struct {
