@@ -326,7 +326,7 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 	} \
 
 #define KLR_CALL(ctx, n, shift, mn) { \
-		KLR_MOV(ctx, sfp[n].o, knh_Method_ufind(ctx, knh_Object_cid(sfp[n+1].o), mn)); \
+		KLR_MOV(ctx, sfp[n].o, konoha_lookupMethod(ctx, knh_Object_cid(sfp[n+1].o), mn)); \
 		DBG2_ASSERT(IS_Method(sfp[n].o)); \
 		((Context*)ctx)->esp = &(sfp[n + shift]); \
 		sfp[n].pc = (sfp[n].mtd)->pc_start; \
@@ -336,7 +336,7 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 	} \
 
 #define KLR_ACALL(ctx, n, shift, mn) { \
-		Method *mtd_ = knh_Method_ufind(ctx, knh_Object_cid(sfp[n+1].o), mn);\
+		Method *mtd_ = konoha_lookupMethod(ctx, knh_Object_cid(sfp[n+1].o), mn);\
 		KLR_MOV(ctx, sfp[n].o, mtd_); \
 		((Context*)ctx)->esp = &(sfp[n + shift]); \
 		knh_sfp_typecheck(ctx, sfp + n + 1, mtd_, pc); \
@@ -389,7 +389,7 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 	} \
 
 #define JIT_CALL(ctx, n, shift, mn) { \
-		KLR_MOV(ctx, sfp[n].o, knh_Method_ufind(ctx, knh_Object_cid(sfp[n+1].o), mn)); \
+		KLR_MOV(ctx, sfp[n].o, konoha_lookupMethod(ctx, knh_Object_cid(sfp[n+1].o), mn)); \
 		DBG2_ASSERT(IS_Method(sfp[n].o)); \
 		((Context*)ctx)->esp = &(sfp[n + shift]); \
 		sfp[n].pc = (sfp[n].mtd)->pc_start; \
@@ -398,7 +398,7 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 	} \
 
 #define JIT_ACALL(ctx, n, shift, mn) { \
-		Method *mtd_ = knh_Method_ufind(ctx, knh_Object_cid(sfp[n+1].o), mn);\
+		Method *mtd_ = konoha_lookupMethod(ctx, knh_Object_cid(sfp[n+1].o), mn);\
 		KLR_MOV(ctx, sfp[n].o, mtd_); \
 		((Context*)ctx)->esp = &(sfp[n + shift]); \
 		knh_sfp_typecheck(ctx, sfp + n + 1, mtd_, NULL); \
@@ -435,7 +435,7 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 		knh_cwb_t cwb = new_cwb(ctx);\
 		KLR_MOV(ctx, sfp[n+2].o, cwb.w);\
 		KLR_MOV(ctx, sfp[n+3].o, fmt);\
-		Method *mtd_ = knh_tMethod_findMT(ctx, knh_Object_cid(sfp[n+1].o), mn);\
+		Method *mtd_ = konoha_lookupFormatter(ctx, knh_Object_cid(sfp[n+1].o), mn);\
 		KLR_SCALL(ctx, n, 4, mtd_);\
 		KLR_MOV(ctx, sfp[n].o, new_String__cwb(ctx, cwb)); \
 	}\
@@ -447,7 +447,7 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 		knh_cwb_t cwb = new_cwb(ctx);\
 		KLR_MOV(ctx, sfp[n+2].o, cwb.w);\
 		KLR_MOV(ctx, sfp[n+3].o, fmt);\
-		Method *mtd_ = knh_tMethod_findMT(ctx, knh_Object_cid(sfp[n+1].o), mn);\
+		Method *mtd_ = konoha_lookupFormatter(ctx, knh_Object_cid(sfp[n+1].o), mn);\
 		JIT_SCALL(ctx, n, 4, mtd_);\
 		KLR_MOV(ctx, sfp[n].o, new_String__cwb(ctx, cwb)); \
 	}\
@@ -802,7 +802,7 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 /* ------------------------------------------------------------------------ */
 
 #define KLR_iCAST(ctx, a) {\
-		knh_integer_t n_ = (knh_integer_t)sfp[a].fvalue; \
+		knh_int_t n_ = (knh_int_t)sfp[a].fvalue; \
 		sfp[a].ivalue = n_; \
 	}\
 
@@ -810,7 +810,7 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 		if(IS_NULL(sfp[a].o)) { \
 			sfp[a].ivalue = 0; \
 		}else{\
-			knh_integer_t n_ = (knh_integer_t)sfp[a].fvalue; \
+			knh_int_t n_ = (knh_int_t)sfp[a].fvalue; \
 			sfp[a].ivalue = n_; \
 		}\
 	}\
