@@ -62,8 +62,8 @@ static METHOD knh__Array_new__array(Ctx *ctx, knh_sfp_t *sfp)
 	Array *o = (Array*)sfp[0].o;
 	int init = p_int(sfp[1]);
 	if(init > 0) {
-		knh_class_t p1 = ctx->tClass[knh_Object_cid(o)].p1;
-		Object *v = konoha_getClassDefaultValue(ctx, p1);
+		knh_class_t p1 = ctx->share->ClassTable[knh_Object_cid(o)].p1;
+		Object *v = konoha_geClassTableDefaultValue(ctx, p1);
 		knh_Array_grow(ctx, o, init, v);
 		o->size = init;
 	}
@@ -92,22 +92,22 @@ static METHOD knh__Array_new__init(Ctx *ctx, knh_sfp_t *sfp)
 /* [IArray] */
 
 static
-void knh_IArray_grow(Ctx *ctx, IArray *a, size_t newsize, knh_integer_t v)
+void knh_IArray_grow(Ctx *ctx, IArray *a, size_t newsize, knh_int_t v)
 {
 	KNH_ASSERT(a->capacity < newsize);
 	size_t i;
-	if(newsize == 0) newsize = (KNH_FASTMALLOC_SIZE / sizeof(knh_integer_t));
-	knh_integer_t *newa = (knh_integer_t*)KNH_MALLOC(ctx, sizeof(knh_integer_t) * newsize);
+	if(newsize == 0) newsize = (KNH_FASTMALLOC_SIZE / sizeof(knh_int_t));
+	knh_int_t *newa = (knh_int_t*)KNH_MALLOC(ctx, sizeof(knh_int_t) * newsize);
 	if(a->capacity > 0) {
-		knh_memcpy(newa, a->ilist, sizeof(knh_integer_t) * a->capacity);
+		knh_memcpy(newa, a->ilist, sizeof(knh_int_t) * a->capacity);
 	}
 	for(i = a->capacity; i < newsize; i++) {
 		newa[i] =  v;
 	}
-	knh_integer_t *olda = a->ilist;
+	knh_int_t *olda = a->ilist;
 	a->ilist = newa;
 	if(a->capacity > 0) {
-		KNH_FREE(ctx, olda, sizeof(knh_integer_t) * a->capacity);
+		KNH_FREE(ctx, olda, sizeof(knh_int_t) * a->capacity);
 	}
 	a->capacity = newsize;
 }
@@ -115,10 +115,10 @@ void knh_IArray_grow(Ctx *ctx, IArray *a, size_t newsize, knh_integer_t v)
 /* ------------------------------------------------------------------------ */
 
 static
-void knh_IArray_add(Ctx *ctx, IArray *o, knh_integer_t value)
+void knh_IArray_add(Ctx *ctx, IArray *o, knh_int_t value)
 {
 	if(o->size == o->capacity) {
-		knh_IArray_grow(ctx, o, knh_array_newsize(o->capacity * 2, sizeof(knh_integer_t)), 0);
+		knh_IArray_grow(ctx, o, knh_array_newsize(o->capacity * 2, sizeof(knh_int_t)), 0);
 	}
 	DBG2_ASSERT(o->size < o->capacity);
 	o->ilist[o->size] = value;
@@ -297,7 +297,7 @@ static METHOD knh__IArray_add(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	IArray *o = (IArray*)sfp[0].o;
 	if(o->size == o->capacity) {
-		knh_IArray_grow(ctx, o, knh_array_newsize(o->capacity * 2, sizeof(knh_integer_t)), 0);
+		knh_IArray_grow(ctx, o, knh_array_newsize(o->capacity * 2, sizeof(knh_int_t)), 0);
 	}
 	o->ilist[o->size] = sfp[1].ivalue;
 	o->size++;
@@ -504,7 +504,7 @@ static METHOD knh__Array_opOffset(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	size_t s = IS_NULL(sfp[1].o) ? 0 : knh_array_index(ctx, p_int(sfp[1]), o->size);
-	knh_int_t e = IS_NULL(sfp[1].o) ? o->size : s + p_int(sfp[2]);
+	knh_intptr_t e = IS_NULL(sfp[1].o) ? o->size : s + p_int(sfp[2]);
 	if(e > o->size) e = o->size; else if(e < 0) e = 0;
 	KNH_RETURN(ctx, sfp, new_Array__subset(ctx, o, s, e));
 }
@@ -697,8 +697,8 @@ static METHOD knh__Array_shuffle(Ctx *ctx, knh_sfp_t *sfp)
 
 static int qsort_icmp(const void* ap, const void* bp)
 {
-	knh_integer_t a = *((knh_integer_t*)ap);
-	knh_integer_t b = *((knh_integer_t*)bp);
+	knh_int_t a = *((knh_int_t*)ap);
+	knh_int_t b = *((knh_int_t*)bp);
 	if(a < b) return -1;
 	if(a > b) return 1;
 	return 0;
@@ -711,7 +711,7 @@ static METHOD knh__IArray_sort(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	IArray *o = (IArray*)sfp[0].o;
-	knh_qsort(o->ilist, o->size, sizeof(knh_integer_t), qsort_icmp);
+	knh_qsort(o->ilist, o->size, sizeof(knh_int_t), qsort_icmp);
 	L_RETURN:;
 	KNH_RETURN_void(ctx, sfp);
 }
@@ -726,7 +726,7 @@ static METHOD knh__IArray_reverse(Ctx *ctx, knh_sfp_t *sfp)
 	size_t i;
 	for(i = 0; i < o->size / 2; i++) {
 		size_t n = o->size - i;
-		knh_integer_t temp = o->ilist[i];
+		knh_int_t temp = o->ilist[i];
 		o->ilist[i] = o->ilist[n];
 		o->ilist[n] = temp;
 	}
@@ -743,7 +743,7 @@ static METHOD knh__IArray_swap(Ctx *ctx, knh_sfp_t *sfp)
 	IArray *o = (IArray*)sfp[0].o;
 	size_t m = knh_array_index(ctx, p_int(sfp[1]), o->size);
 	size_t n = knh_array_index(ctx, p_int(sfp[2]), o->size);
-	knh_integer_t temp = o->ilist[n];
+	knh_int_t temp = o->ilist[n];
 	o->ilist[n] = o->ilist[m];
 	o->ilist[m] = temp;
 	L_RETURN:;
@@ -761,7 +761,7 @@ static METHOD knh__IArray_shuffle(Ctx *ctx, knh_sfp_t *sfp)
 	for(i = 0; i < o->size; i++) {
 		size_t m = knh_rand() % o->size;
 		size_t n = knh_rand() % o->size;
-		knh_integer_t temp = o->ilist[n];
+		knh_int_t temp = o->ilist[n];
 		o->ilist[n] = o->ilist[m];
 		o->ilist[m] = temp;
 	}
@@ -891,7 +891,7 @@ ITRNEXT knh_Array_var_next(Ctx *ctx, knh_sfp_t *sfp, int n)
 MAPPER knh_Array_Iterator(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_MAPPED(ctx, sfp,
-		new_Iterator(ctx, ctx->tClass[(sfp[0].o)->h.cid].p1, sfp[0].o, knh_Array_var_next));
+		new_Iterator(ctx, ctx->share->ClassTable[(sfp[0].o)->h.cid].p1, sfp[0].o, knh_Array_var_next));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -900,7 +900,7 @@ MAPPER knh_Array_Iterator(Ctx *ctx, knh_sfp_t *sfp)
 static METHOD knh__Array_opItr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
-	KNH_RETURN(ctx, sfp, new_Iterator(ctx, ctx->tClass[o->h.cid].p1, UP(o), knh_Array_var_next));
+	KNH_RETURN(ctx, sfp, new_Iterator(ctx, ctx->share->ClassTable[o->h.cid].p1, UP(o), knh_Array_var_next));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -909,7 +909,7 @@ static METHOD knh__Array_opItr(Ctx *ctx, knh_sfp_t *sfp)
 MAPPER knh_Iterator_Array(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Iterator *it = sfp[0].it;
-	Array *a = new_Array(ctx, ctx->tClass[it->h.cid].p1, 0);
+	Array *a = new_Array(ctx, ctx->share->ClassTable[it->h.cid].p1, 0);
 	it->fnext_1(ctx, sfp, 1);
 	while(HAS_ITRNEXT(sfp[1].o)) {
 		knh_Array_add(ctx, a, sfp[1].o);
@@ -923,9 +923,9 @@ MAPPER knh_Iterator_Array(Ctx *ctx, knh_sfp_t *sfp)
 Mapper *knh_tMapper_newIteratorArray(Ctx *ctx, knh_class_t icid, knh_class_t acid)
 {
 	Mapper *mpr = new_Mapper(ctx, KNH_FLAG_MMF_TOTAL, acid, icid, knh_Array_Iterator, KNH_NULL);
-	knh_ClassMap_add(ctx, ctx->tClass[acid].cmap, mpr);
+	knh_ClassMap_add(ctx, ctx->share->ClassTable[acid].cmap, mpr);
 	mpr = new_Mapper(ctx, KNH_FLAG_MMF_TOTAL, icid, acid, knh_Iterator_Array, KNH_NULL);
-	knh_ClassMap_add(ctx, ctx->tClass[icid].cmap, mpr);
+	knh_ClassMap_add(ctx, ctx->share->ClassTable[icid].cmap, mpr);
 	return mpr;
 }
 
@@ -934,9 +934,9 @@ Mapper *knh_tMapper_newIteratorArray(Ctx *ctx, knh_class_t icid, knh_class_t aci
 Mapper *knh_tMapper_newArrayIterator(Ctx *ctx, knh_class_t acid, knh_class_t icid)
 {
 	Mapper *mpr = new_Mapper(ctx, KNH_FLAG_MMF_TOTAL, icid, acid, knh_Iterator_Array, KNH_NULL);
-	knh_ClassMap_add(ctx, ctx->tClass[icid].cmap, mpr);
+	knh_ClassMap_add(ctx, ctx->share->ClassTable[icid].cmap, mpr);
 	mpr = new_Mapper(ctx, KNH_FLAG_MMF_TOTAL, acid, icid, knh_Array_Iterator, KNH_NULL);
-	knh_ClassMap_add(ctx, ctx->tClass[acid].cmap, mpr);
+	knh_ClassMap_add(ctx, ctx->share->ClassTable[acid].cmap, mpr);
 	return mpr;
 }
 
@@ -979,8 +979,8 @@ void knh_ArrayDim_init(Ctx *ctx, Array *a, size_t x, size_t y, size_t z)
 	knh_Array_setDim(a, 1);
 	a->list = (Object**)knh_array_dmalloc(ctx, x, y, z, sizeof(Object*));
 	a->capacity = x * y * z;
-	knh_class_t p1 = ctx->tClass[knh_Object_cid(a)].p1;
-	Object *v = (p1 == CLASS_Any) ? KNH_NULL : konoha_getClassDefaultValue(ctx, p1);
+	knh_class_t p1 = ctx->share->ClassTable[knh_Object_cid(a)].p1;
+	Object *v = (p1 == CLASS_Any) ? KNH_NULL : konoha_geClassTableDefaultValue(ctx, p1);
 	int i = 0;
 	for(i = 0; i < a->capacity; i++) {
 		KNH_INITv(a->list[i], v);
@@ -1071,7 +1071,7 @@ static
 void knh_IArrayDim_init(Ctx *ctx, IArray *a, size_t x, size_t y, size_t z)
 {
 	knh_IArray_setDim(a, 1);
-	a->ilist = (knh_integer_t*)knh_array_dmalloc(ctx, x, y, z, sizeof(knh_integer_t));
+	a->ilist = (knh_int_t*)knh_array_dmalloc(ctx, x, y, z, sizeof(knh_int_t));
 	a->capacity = x * y * z;
 	int i = 0;
 	for(i = 0; i < a->capacity; i++) {
