@@ -43,7 +43,7 @@ extern "C" {
 
 #define _knh_Class_cid(c)     (knh_class_t)(c)->cid
 #define _KNH_FLAG_CF2OF(f)        (f)
-#define _knh_Class_isGenerics(cid)    (ctx->tClass[cid].p1 != CLASS_Nue)
+#define _knh_Class_isGenerics(cid)    (ctx->share->ClassTable[cid].p1 != CLASS_Nue)
 
 /* ------------------------------------------------------------------------ */
 
@@ -55,27 +55,46 @@ extern "C" {
 #define _STRUCT_FIELDSIZE(sid)      (sid & (~KNH_FLAG_SF_FIELD))
 #define _STRUCT_UNMASK(sid)         (sid & (~KNH_FLAG_SF_FIELD))
 
-#define _KNH_ASSERT_sid(sid)   KNH_ASSERT(((knh_struct_t)sid) < ctx->share->tStructSize)
+#define _KNH_ASSERT_sid(sid)   KNH_ASSERT(((knh_struct_t)sid) < ctx->share->StructTableSize)
 
 /* ======================================================================== */
-/* [tClass] */
+/* [ClassTable] */
 
-knh_class_t knh_tClass_newId(Ctx *ctx)
+knh_struct_t knh_StructTable_newId(Ctx *ctx)
 {
 	knh_class_t newid;
-	KNH_LOCK(ctx, ctx->tableLock);
-	if(!(ctx->share->tClassSize < KNH_TCLASS_SIZE)) {
-		KNH_UNLOCK(ctx, ctx->tableLock);
-		KNH_EXIT("Enlarge KNH_TCLASS_SIZE %d", KNH_TCLASS_SIZE);
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+	size_t structmax = ctx->share->ClassTableSize;
+	if(KNH_TSTRUCT_SIZE < structmax) structmax = KNH_TSTRUCT_SIZE;
+	if(!(ctx->share->StructTableSize < structmax)) {
+		KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
+		KNH_EXIT("Enlarge KNH_TSTRUCT_SIZE %d", KNH_TSTRUCT_SIZE);
 		return CLASS_unknown;
 	}
-	newid = ctx->share->tClassSize;
-	ctx->share->tClassSize++;
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	newid = ctx->share->StructTableSize;
+	ctx->share->StructTableSize++;
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 	return newid;
 }
 
-#define _KNH_ASSERT_cid(cid)    KNH_ASSERT(cid < ctx->share->tClassSize)
+/* ------------------------------------------------------------------------ */
+
+knh_class_t knh_ClassTable_newId(Ctx *ctx)
+{
+	knh_class_t newid;
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+	if(ctx->share->StructTableSize < ctx->share->ClassTableSize) {
+		ctx->share->ClassTableSize--;
+		newid = ctx->share->ClassTableSize;
+		KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
+		return newid;
+	}
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
+	KNH_EXIT("Enlarge KNH_TCLASS_SIZE %d", KNH_TCLASS_SIZE);
+	return CLASS_unknown;
+}
+
+#define _KNH_ASSERT_cid(cid)    KNH_ASSERT(cid < KNH_TCLASS_SIZE)
 
 /* ------------------------------------------------------------------------ */
 
@@ -89,19 +108,19 @@ static knh_Class_t *new_Class(Ctx *ctx, knh_class_t cid)
 
 /* ------------------------------------------------------------------------ */
 
-void konoha_setClassName(Ctx *ctx, knh_class_t cid, String *lname)
+void konoha_seClassTableName(Ctx *ctx, knh_class_t cid, String *lname)
 {
 	KNH_ASSERT_cid(cid);
-	KNH_ASSERT(ctx->tClass[cid].class_cid == NULL);
-	KNH_INITv(ctx->tClass[cid].class_cid, new_Class(ctx, cid));
-	KNH_INITv(ctx->tClass[cid].lname, lname);
+	KNH_ASSERT(ctx->share->ClassTable[cid].class_cid == NULL);
+	KNH_INITv(ctx->share->ClassTable[cid].class_cid, new_Class(ctx, cid));
+	KNH_INITv(ctx->share->ClassTable[cid].lname, lname);
 	//DBG2_P("lname='%s'", knh_String_tochar(lname));
-	knh_NameSpace_setClass(ctx, knh_rootNameSpace, lname, cid);
+	knh_NameSpace_seClassTable(ctx, knh_rootNameSpace, lname, cid);
 	{
 		knh_bytes_t n = knh_String_tobytes(lname);
 		knh_index_t idx = knh_bytes_index(n, '{');
 		if(idx != -1) {
-			KNH_INITv(ctx->tClass[cid].sname, lname);
+			KNH_INITv(ctx->share->ClassTable[cid].sname, lname);
 			return;
 		}
 		if(knh_bytes_endsWith(n, STEXT(".."))) {
@@ -113,10 +132,10 @@ void konoha_setClassName(Ctx *ctx, knh_class_t cid, String *lname)
 			idx = knh_bytes_rindex(n, '.');
 		}
 		if(idx == -1) {
-			KNH_INITv(ctx->tClass[cid].sname, lname);
+			KNH_INITv(ctx->share->ClassTable[cid].sname, lname);
 		}
 		else {
-			KNH_INITv(ctx->tClass[cid].sname, new_String(ctx, knh_bytes_last(n, idx + 1), lname));
+			KNH_INITv(ctx->share->ClassTable[cid].sname, new_String(ctx, knh_bytes_last(n, idx + 1), lname));
 		}
 	}
 }
@@ -124,17 +143,17 @@ void konoha_setClassName(Ctx *ctx, knh_class_t cid, String *lname)
 /* ------------------------------------------------------------------------ */
 /* [name] */
 
-#define _CLASSN(cid)   knh_tClass_CLASSN(ctx, cid)
-#define _CLASSNo(o)    knh_tClass_CLASSN(ctx, knh_Object_cid(o))
+#define _CLASSN(cid)   knh_ClassTable_CLASSN(ctx, cid)
+#define _CLASSNo(o)    knh_ClassTable_CLASSN(ctx, knh_Object_cid(o))
 
-char *knh_tClass_CLASSN(Ctx *ctx, knh_class_t cid)
+char *knh_ClassTable_CLASSN(Ctx *ctx, knh_class_t cid)
 {
-	DBG2_ASSERT(cid < ctx->share->tClassSize);
-	if(knh_String_startsWith(ctx->tClass[cid].lname, STEXT("konoha."))) {
-		return knh_String_tochar(ctx->tClass[cid].sname);
+	DBG2_ASSERT(cid < ctx->share->ClassTableSize);
+	if(knh_String_startsWith(ctx->share->ClassTable[cid].lname, STEXT("konoha."))) {
+		return knh_String_tochar(ctx->share->ClassTable[cid].sname);
 	}
 	else {
-		return knh_String_tochar(ctx->tClass[cid].lname);
+		return knh_String_tochar(ctx->share->ClassTable[cid].lname);
 	}
 }
 
@@ -144,7 +163,7 @@ char *knh_tClass_CLASSN(Ctx *ctx, knh_class_t cid)
 static
 knh_Object_t *knh_fdefault__CONST(Ctx *ctx, knh_class_t cid)
 {
-	return ctx->tClass[cid].cspec;
+	return ctx->share->ClassTable[cid].cspec;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -153,23 +172,23 @@ static
 knh_Object_t *knh_fdefault__INIT(Ctx *ctx, knh_class_t cid)
 {
 	//DBG2_P("%s", CLASSN(cid));
-	KNH_ASSERT(IS_NULL(ctx->tClass[cid].cspec));
-	Object *v = new_Object_init(ctx, ctx->tClass[cid].oflag | KNH_FLAG_OF_IMMUTABLE, cid, 0);
-	KNH_SETv(ctx, ctx->tClass[cid].cspec, v);
-	ctx->tClass[cid].fdefault = knh_fdefault__CONST;
-	return ctx->tClass[cid].cspec;
+	KNH_ASSERT(IS_NULL(ctx->share->ClassTable[cid].cspec));
+	Object *v = new_Object_init(ctx, ctx->share->ClassTable[cid].oflag | KNH_FLAG_OF_IMMUTABLE, cid, 0);
+	KNH_SETv(ctx, ctx->share->ClassTable[cid].cspec, v);
+	ctx->share->ClassTable[cid].fdefault = knh_fdefault__CONST;
+	return ctx->share->ClassTable[cid].cspec;
 }
 
 /* ------------------------------------------------------------------------ */
 
-void konoha_setClassDefaultValue(Ctx *ctx, knh_class_t cid, Object *value, knh_fdefault fdefault)
+void konoha_seClassTableDefaultValue(Ctx *ctx, knh_class_t cid, Object *value, knh_fdefault fdefault)
 {
 	KNH_ASSERT_cid(cid);
-	if(ctx->tClass[cid].cspec == NULL) {
-		KNH_INITv(ctx->tClass[cid].cspec, value);
+	if(ctx->share->ClassTable[cid].cspec == NULL) {
+		KNH_INITv(ctx->share->ClassTable[cid].cspec, value);
 	}
 	else {
-		KNH_SETv(ctx, ctx->tClass[cid].cspec, value);
+		KNH_SETv(ctx, ctx->share->ClassTable[cid].cspec, value);
 	}
 	if(fdefault == NULL) {
 		if(IS_NULL(value) && cid != CLASS_Nue) {
@@ -179,29 +198,29 @@ void konoha_setClassDefaultValue(Ctx *ctx, knh_class_t cid, Object *value, knh_f
 			fdefault = knh_fdefault__CONST;
 		}
 	}
-	ctx->tClass[cid].fdefault = fdefault;
+	ctx->share->ClassTable[cid].fdefault = fdefault;
 }
 
 /* ------------------------------------------------------------------------ */
 
-#define _KNH_DEF(ctx, cid)  konoha_getClassDefaultValue(ctx, cid)
+#define _KNH_DEF(ctx, cid)  konoha_geClassTableDefaultValue(ctx, cid)
 
-Object *konoha_getClassDefaultValue(Ctx *ctx, knh_class_t cid)
+Object *konoha_geClassTableDefaultValue(Ctx *ctx, knh_class_t cid)
 {
 	KNH_ASSERT_cid(cid);
-	return ctx->tClass[cid].fdefault(ctx, cid);
+	return ctx->share->ClassTable[cid].fdefault(ctx, cid);
 }
 
 /* ------------------------------------------------------------------------ */
 
-#define _KNH_DEF(ctx, cid)  konoha_getClassDefaultValue(ctx, cid)
+#define _KNH_DEF(ctx, cid)  konoha_geClassTableDefaultValue(ctx, cid)
 
 Object *konoha_getDefaultValue(Ctx *ctx, knh_type_t type)
 {
 	if(IS_NNTYPE(type)) {
 		knh_class_t cid = CLASS_type(type);
 		KNH_ASSERT_cid(cid);
-		return ctx->tClass[cid].fdefault(ctx, cid);
+		return ctx->share->ClassTable[cid].fdefault(ctx, cid);
 	}
 	else {
 		return KNH_NULL;
@@ -211,12 +230,12 @@ Object *konoha_getDefaultValue(Ctx *ctx, knh_type_t type)
 /* ======================================================================== */
 /* [PARAM] */
 
-void konoha_setClassParam(Ctx *ctx, knh_class_t cid, knh_class_t p1, knh_class_t p2)
+void konoha_seClassTableParam(Ctx *ctx, knh_class_t cid, knh_class_t p1, knh_class_t p2)
 {
 	KNH_ASSERT_cid(cid);
-	//KNH_ASSERT(ctx->tClass[cid].p1 == CLASS_Nue);
-	ctx->tClass[cid].p1 = p1;
-	ctx->tClass[cid].p2 = p2;
+	//KNH_ASSERT(ctx->share->ClassTable[cid].p1 == CLASS_Nue);
+	ctx->share->ClassTable[cid].p1 = p1;
+	ctx->share->ClassTable[cid].p2 = p2;
 	if(!knh_class_isCyclic(cid)) {
 		if(knh_class_isCyclic(p1) || knh_class_isCyclic(p2)) {
 			knh_class_setCyclic(cid, 1);
@@ -230,35 +249,34 @@ knh_class_t
 konoha_addGenericsClass(Ctx *ctx, knh_class_t cid, String *name, knh_class_t bcid, knh_class_t p1, knh_class_t p2)
 {
 	if(cid == CLASS_newid) {
-		cid = knh_tClass_newId(ctx);
+		cid = knh_ClassTable_newId(ctx);
 	}else {
-		if(!(cid < ctx->share->tClassSize)) {
-			ctx->share->tClassSize = cid + 1;
-		}
+		KNH_ASSERT(cid + 1 == ctx->share->ClassTableSize);
+		ctx->share->ClassTableSize = cid;
 	}
-	knh_tClass_t *TC = (knh_tClass_t*)(&ctx->tClass[cid]);
+	knh_ClassTable_t *TC = (knh_ClassTable_t*)(&ctx->share->ClassTable[cid]);
 	KNH_ASSERT(bcid < cid);
-	KNH_ASSERT(ctx->tClass[cid].class_cid == NULL);
+	KNH_ASSERT(ctx->share->ClassTable[cid].class_cid == NULL);
 
-	TC->cflag  = ctx->tClass[bcid].cflag;
-	TC->oflag  = ctx->tClass[bcid].oflag;
+	TC->cflag  = ctx->share->ClassTable[bcid].cflag;
+	TC->oflag  = ctx->share->ClassTable[bcid].oflag;
 
-	TC->sid    = ctx->tClass[bcid].sid;
+	TC->sid    = ctx->share->ClassTable[bcid].sid;
 
 	TC->bcid   = bcid;
-	TC->supcid = ctx->tClass[bcid].supcid;
+	TC->supcid = ctx->share->ClassTable[bcid].supcid;
 	//TC->supcid = bcid;
 
-	TC->offset = ctx->tClass[bcid].offset;
+	TC->offset = ctx->share->ClassTable[bcid].offset;
 
-	TC->size = ctx->tClass[bcid].size;
-	TC->bsize  = ctx->tClass[bcid].bsize;
+	TC->size = ctx->share->ClassTable[bcid].size;
+	TC->bsize  = ctx->share->ClassTable[bcid].bsize;
 
-	konoha_setClassName(ctx, cid, name);
-	KNH_INITv(TC->cstruct, ctx->tClass[bcid].cstruct);
+	konoha_seClassTableName(ctx, cid, name);
+	KNH_INITv(TC->cstruct, ctx->share->ClassTable[bcid].cstruct);
 	KNH_INITv(TC->cmap, new_ClassMap0(ctx, 0));
-	konoha_setClassDefaultValue(ctx, cid, KNH_NULL, NULL);
-	konoha_setClassParam(ctx, cid, p1, p2);
+	konoha_seClassTableDefaultValue(ctx, cid, KNH_NULL, NULL);
+	konoha_seClassTableParam(ctx, cid, p1, p2);
 	return cid;
 }
 
@@ -283,17 +301,17 @@ knh_index_t knh_Class_indexOfField(Ctx *ctx, knh_class_t cid, knh_fieldn_t fn)
 	KNH_ASSERT_cid(cid);
 	{
 		knh_index_t idx = -1;
-		ClassStruct *cs = ctx->tClass[cid].cstruct;
+		ClassStruct *cs = ctx->share->ClassTable[cid].cstruct;
 		if(cs->fields != NULL) {
 			for(idx = 0; idx < cs->fsize; idx++) {
 				if(cs->fields[idx].fn == fn) {
-					return ctx->tClass[cid].offset + idx;
+					return ctx->share->ClassTable[cid].offset + idx;
 				}
 			}
 			idx = -1;
 		}
-		if(ctx->tClass[cid].offset == 0) return -1;
-		cid = ctx->tClass[cid].supcid;
+		if(ctx->share->ClassTable[cid].offset == 0) return -1;
+		cid = ctx->share->ClassTable[cid].supcid;
 	}
 	goto L_TAIL;
 }
@@ -306,7 +324,7 @@ knh_index_t knh_Class_queryField(Ctx *ctx, knh_class_t cid, knh_fieldn_t fnq)
 	L_TAIL:;
 	KNH_ASSERT_cid(cid);
 	{
-		ClassStruct *cs = ctx->tClass[cid].cstruct;
+		ClassStruct *cs = ctx->share->ClassTable[cid].cstruct;
 		knh_index_t idx = -1;
 		if(FIELDN_IS_SUPER(fnq)) {
 			fnq = fn;
@@ -315,14 +333,14 @@ knh_index_t knh_Class_queryField(Ctx *ctx, knh_class_t cid, knh_fieldn_t fnq)
 		if(cs->fields != NULL) {
 			for(idx = 0; idx < cs->fsize; idx++) {
 				if(cs->fields[idx].fn == fn) {
-					return ctx->tClass[cid].offset + idx;
+					return ctx->share->ClassTable[cid].offset + idx;
 				}
 			}
 			idx = -1;
 		}
 		L_SUPER:;
-		if(ctx->tClass[cid].offset == 0) return -1;
-		cid = ctx->tClass[cid].supcid;
+		if(ctx->share->ClassTable[cid].offset == 0) return -1;
+		cid = ctx->share->ClassTable[cid].supcid;
 		goto L_TAIL;
 	}
 }
@@ -332,11 +350,11 @@ knh_index_t knh_Class_queryField(Ctx *ctx, knh_class_t cid, knh_fieldn_t fnq)
 knh_cfield_t *knh_Class_fieldAt(Ctx *ctx, knh_class_t cid, size_t n)
 {
 	KNH_ASSERT_cid(cid);
-	KNH_ASSERT(0 <= n && n < ctx->tClass[cid].size);
+	KNH_ASSERT(0 <= n && n < ctx->share->ClassTable[cid].size);
 	L_TAIL:;
 	{
-		ClassStruct *cs = ctx->tClass[cid].cstruct;;
-		size_t offset = ctx->tClass[cid].offset;
+		ClassStruct *cs = ctx->share->ClassTable[cid].cstruct;;
+		size_t offset = ctx->share->ClassTable[cid].offset;
 		if(offset <= n) {
 			if(cs->fields == NULL) {
 				return NULL;
@@ -346,7 +364,7 @@ knh_cfield_t *knh_Class_fieldAt(Ctx *ctx, knh_class_t cid, size_t n)
 			}
 		}
 		KNH_ASSERT_cid(cid);
-		cid = ctx->tClass[cid].supcid;
+		cid = ctx->share->ClassTable[cid].supcid;
 	}
 	goto L_TAIL;
 }
@@ -383,17 +401,17 @@ ClassMap* new_ClassMap0(Ctx *ctx, knh_ushort_t capacity)
 
 int knh_ClassMap_isDefault(Ctx *ctx, ClassMap *o)
 {
-	return (o == ctx->tClass[CLASS_Any].cmap);
+	return (o == ctx->share->ClassTable[CLASS_Any].cmap);
 }
 
 /* ------------------------------------------------------------------------ */
 
-void knh_tClass_readyClassMap(Ctx *ctx, knh_class_t cid)
+void knh_ClassTable_readyClassMap(Ctx *ctx, knh_class_t cid)
 {
 	KNH_ASSERT_cid(cid);
 	KNH_ASSERT(cid != CLASS_Any);
-	if(ctx->tClass[cid].cmap == ctx->tClass[CLASS_Any].cmap) {
-		KNH_SETv(ctx, ctx->tClass[cid].cmap, new_ClassMap0(ctx, 4));
+	if(ctx->share->ClassTable[cid].cmap == ctx->share->ClassTable[CLASS_Any].cmap) {
+		KNH_SETv(ctx, ctx->share->ClassTable[cid].cmap, new_ClassMap0(ctx, 4));
 	}
 }
 
@@ -403,7 +421,7 @@ void knh_ClassMap_resize(Ctx *ctx, ClassMap *o, size_t newsize)
 {
 	Mapper **newlist = (Mapper**)KNH_MALLOC(ctx, newsize * sizeof(Mapper*));
 	knh_bzero(newlist, newsize);
-	knh_int_t i;
+	knh_intptr_t i;
 	for(i = 0; i < DP(o)->size; i++) {
 		newlist[i] = DP(o)->maplist[i];
 	}
@@ -496,9 +514,9 @@ void knh_ClassMap__man(Ctx *ctx, ClassMap *o, OutputStream *w, knh_class_t cid)
 		knh_write_cid(ctx, w, DP(mpr)->tcid);
 		knh_write_EOL(ctx, w);
 	}
-	if(ctx->tClass[cid].supcid != CLASS_Object) {
-		cid = ctx->tClass[cid].supcid;
-		o = ctx->tClass[cid].cmap;
+	if(ctx->share->ClassTable[cid].supcid != CLASS_Object) {
+		cid = ctx->share->ClassTable[cid].supcid;
+		o = ctx->share->ClassTable[cid].cmap;
 		from = 0;
 		goto L_TAIL;
 	}
