@@ -81,6 +81,66 @@ METHOD knh__Closure_callcc(Ctx *ctx, knh_sfp_t *sfp)
 	(sfp[0].cc)->fcallcc_2(ctx, sfp);
 }
 
+/* ------------------------------------------------------------------------ */
+
+//#define _knh_Closure_binvokef(ctx, c, fmt, ...)  ((knh_Closure_invokef(ctx, c, fmt, ## __VA_ARGS__))->bvalue)
+//#define _knh_Closure_iinvokef(ctx, c, fmt, ...)  ((knh_Closure_invokef(ctx, c, fmt, ## __VA_ARGS__))->ivalue)
+//#define _knh_Closure_finvokef(ctx, c, fmt, ...)  ((knh_Closure_invokef(ctx, c, fmt, ## __VA_ARGS__))->fvalue)
+//#define _knh_Closure_sinvokef(ctx, c, fmt, ...)  knh_String_tochar((knh_Closure_invokef(ctx, c, fmt, ## __VA_ARGS__))->s)
+
+// knh_Closure_finvoke(ctx, c, "oo", sfp[1].o, sfp[2].o)
+// knh_Closure_finvoke(ctx, c, "ii", 1, 2)
+
+KNHAPI(knh_sfp_t*) knh_Closure_finvoke(Ctx *ctx, Closure *c, const char *fmt, ...)
+{
+	char *p = (char*)fmt;
+	knh_sfp_t *lsfp = KNH_LOCAL(ctx);
+	int ch, n = 2;
+	va_list args;
+	va_start(args , fmt);
+	while((ch = *p) != '\0') {
+		p++;
+		switch(ch) {
+		case '%':
+		break;
+		case 'i': case 'u': case 'd':
+			KNH_SETv(ctx, lsfp[n].o, KNH_INT0); // NONNULL
+			lsfp[n].ivalue = (knh_int_t)va_arg(args, knh_int_t);
+			n++;
+		break;
+		case 'f':
+			KNH_SETv(ctx, lsfp[n].o, KNH_FLOAT0);  // NONNULL
+			lsfp[n].fvalue = (knh_float_t)va_arg(args, knh_float_t);
+			n++;
+		break;
+		case 'o':
+		{
+			Int *num = (Int*)va_arg(args, knh_Object_t*);
+			KNH_SETv(ctx, lsfp[n].o, num);
+			lsfp[n].data = num->n.data;
+			n++;
+		}
+		break;
+		case 's':
+		{
+			char *s = (char*)va_arg(args, char*);
+			KNH_SETv(ctx, lsfp[n].o, new_String(ctx, B(s), NULL));
+			n++;
+		}
+		break;
+		}/*switch*/
+	} /* while */
+	va_end(args);
+	DBG2_P("argc=%d", n - 2);
+	if((c)->finvoke_1 != knh__Delegate_scall) {
+		KNH_ABORT();
+	}
+	KNH_MOV(ctx, lsfp[1].o, DP(c)->base);
+	KNH_SCALL(ctx, lsfp, 0, DP(c)->mtd, n - 2);
+	KNH_LOCALBACK(ctx, lsfp);
+	return lsfp;
+}
+
 ///* ------------------------------------------------------------------------ */
 //
 //static
@@ -182,8 +242,8 @@ METHOD knh__Closure_callcc(Ctx *ctx, knh_sfp_t *sfp)
 //	knh_type_t rtype = knh_pmztype_totype(ctx, knh_Method_rztype(mtd), cid);
 //	cid = CLASS_type(rtype);
 //	KNH_ASSERT_cid(cid);
-//	KNH_ASSERT(ctx->tClass[cid].bcid == CLASS_Iterator);
-//	return ctx->tClass[cid].p1;
+//	KNH_ASSERT(ctx->share->ClassTable[cid].bcid == CLASS_Iterator);
+//	return ctx->share->ClassTable[cid].p1;
 //}
 //
 ///* ------------------------------------------------------------------------ */
@@ -246,7 +306,7 @@ METHOD knh__Closure_callcc(Ctx *ctx, knh_sfp_t *sfp)
 //	}
 //	KNH_RETURN(ctx, sfp, new_Generator(ctx, mtd, sfp, esp));
 //}
-//
+
 /* ------------------------------------------------------------------------ */
 /* class */
 /* ------------------------------------------------------------------------ */
@@ -269,7 +329,7 @@ Closure* new_ClosureDEFAULT(Ctx *ctx, knh_type_t rtype, knh_class_t cid)
 	Closure *c = (Closure*)new_Object_init(ctx, FLAG_Closure, cid, 0);
 	Method *mtd = new_Method(ctx, 0, cid, METHODN_lambda, knh_fmethod_closureDEFAULT);
 	KNH_SETv(ctx, DP(c)->mtd, mtd);
-	KNH_SETv(ctx, DP(mtd)->mf, knh_tMethodField_find0(ctx, rtype));
+	KNH_SETv(ctx, DP(mtd)->mf, konoha_findMethodField0(ctx, rtype));
 	knh_Method_setVarArgs(mtd, 1);
 	KNH_SETv(ctx, DP(c)->base, KNH_NULL);
 	(c)->finvoke_1 = knh__Delegate_scall;
@@ -283,34 +343,33 @@ knh_class_t
 konoha_addClosureClass(Ctx *ctx, knh_class_t cid, String *name, knh_type_t r0, knh_type_t p1, knh_type_t p2, knh_type_t p3)
 {
 	if(cid == CLASS_newid) {
-		cid = knh_tClass_newId(ctx);
+		cid = knh_ClassTable_newId(ctx);
 	}else {
-		if(!(cid < ctx->share->tClassSize)) {
-			ctx->share->tClassSize = cid + 1;
-		}
+		KNH_ASSERT(cid + 1 == ctx->share->ClassTableSize);
+		ctx->share->ClassTableSize = cid;
 	}
-	knh_tClass_t *TC = (knh_tClass_t*)(&ctx->tClass[cid]);
-	KNH_ASSERT(ctx->tClass[cid].class_cid == NULL);
+	knh_ClassTable_t *TC = (knh_ClassTable_t*)(&ctx->share->ClassTable[cid]);
+	KNH_ASSERT(ctx->share->ClassTable[cid].class_cid == NULL);
 
-	TC->cflag  = ctx->tClass[CLASS_Closure].cflag;
-	TC->oflag  = ctx->tClass[CLASS_Closure].oflag;
-	TC->sid    = ctx->tClass[CLASS_Closure].sid;
+	TC->cflag  = ctx->share->ClassTable[CLASS_Closure].cflag;
+	TC->oflag  = ctx->share->ClassTable[CLASS_Closure].oflag;
+	TC->sid    = ctx->share->ClassTable[CLASS_Closure].sid;
 
 	TC->bcid   = CLASS_Closure;
-	TC->supcid = ctx->tClass[CLASS_Closure].supcid;
-	TC->offset = ctx->tClass[CLASS_Closure].offset;
+	TC->supcid = ctx->share->ClassTable[CLASS_Closure].supcid;
+	TC->offset = ctx->share->ClassTable[CLASS_Closure].offset;
 
-	TC->size = ctx->tClass[CLASS_Closure].size;
-	TC->bsize  = ctx->tClass[CLASS_Closure].bsize;
+	TC->size = ctx->share->ClassTable[CLASS_Closure].size;
+	TC->bsize  = ctx->share->ClassTable[CLASS_Closure].bsize;
 
-	konoha_setClassName(ctx, cid, name);
-	KNH_INITv(TC->cstruct, ctx->tClass[CLASS_Closure].cstruct);
-	KNH_INITv(TC->cmap, ctx->tClass[CLASS_Closure].cmap);
+	konoha_seClassTableName(ctx, cid, name);
+	KNH_INITv(TC->cstruct, ctx->share->ClassTable[CLASS_Closure].cstruct);
+	KNH_INITv(TC->cmap, ctx->share->ClassTable[CLASS_Closure].cmap);
 	TC->r0 = r0;
 	TC->p1 = p1;
 	TC->p2 = p2;
 	TC->p3 = p3;
-	konoha_setClassDefaultValue(ctx, cid, UP(new_ClosureDEFAULT(ctx, r0, cid)), NULL);
+	konoha_seClassTableDefaultValue(ctx, cid, UP(new_ClosureDEFAULT(ctx, r0, cid)), NULL);
 	return cid;
 }
 
@@ -336,7 +395,7 @@ knh_class_t knh_class_Closure(Ctx *ctx, knh_type_t r0, knh_type_t p1, knh_type_t
 		knh_format_type(ctx, tb3, sizeof(tb3), p3);
 		knh_snprintf(buf, sizeof(buf), "%s(%s,%s,%s)", tb0, tb1, tb2, tb3);
 	}
-	knh_class_t cid = knh_NameSpace_getClass(ctx, knh_rootNameSpace, B(buf));
+	knh_class_t cid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, B(buf));
 	if(cid == CLASS_unknown) {
 		DBG2_P("*** Generating %s ***", buf);
 		konoha_addClosureClass(ctx, CLASS_newid, new_String(ctx, B(buf), NULL), r0, p1, p2, p3);
