@@ -369,7 +369,7 @@ knh_dict_t *knh_dictmap_malloc(Ctx *ctx, size_t init)
 
 /* ------------------------------------------------------------------------ */
 
-DictMap* new_DictMap0(Ctx *ctx, knh_int_t capacity)
+DictMap* new_DictMap0(Ctx *ctx, knh_intptr_t capacity)
 {
 	knh_DictMap_t *o = (knh_DictMap_t*)new_hObject(ctx, FLAG_DictMap, CLASS_DictMap, CLASS_DictMap);
 	o->_list = knh_dict_malloc(ctx, capacity, knh_dictmap_finit, knh_dictmap_ftraverse, knh_dict_fcmp);
@@ -380,7 +380,7 @@ DictMap* new_DictMap0(Ctx *ctx, knh_int_t capacity)
 
 /* ------------------------------------------------------------------------ */
 
-DictMap* new_DictMap(Ctx *ctx, knh_class_t p1, knh_int_t capacity)
+DictMap* new_DictMap(Ctx *ctx, knh_class_t p1, knh_intptr_t capacity)
 {
 	knh_class_t cid = knh_class_Generics(ctx, CLASS_DictMap, p1, CLASS_Nue);
 	knh_DictMap_t *o = (knh_DictMap_t*)new_hObject(ctx, FLAG_DictMap, CLASS_DictMap, cid);
@@ -452,7 +452,7 @@ String *new_String__DictMap(Ctx *ctx, DictMap *o, knh_bytes_t key)
 Object *knh_DictMap_get__b(Ctx *ctx, DictMap *o, knh_bytes_t key)
 {
 	KNH_ASSERT(IS_bDictMap(o));
-	knh_int_t loc = knh_dict_index_b(o->_list, o->size, o->fcmp, key);
+	knh_intptr_t loc = knh_dict_index_b(o->_list, o->size, o->fcmp, key);
 	return (loc == -1) ? KNH_NULL : o->list[loc].value;
 }
 
@@ -461,7 +461,7 @@ Object *knh_DictMap_get__b(Ctx *ctx, DictMap *o, knh_bytes_t key)
 Object *knh_DictMap_get(Ctx *ctx, DictMap *o, String *key)
 {
 	KNH_ASSERT(IS_bDictMap(o));
-	knh_int_t loc = knh_dict_index_b(o->_list, o->size, o->fcmp, knh_String_tobytes(key));
+	knh_intptr_t loc = knh_dict_index_b(o->_list, o->size, o->fcmp, knh_String_tobytes(key));
 	return (loc == -1) ? KNH_NULL : o->list[loc].value;
 }
 
@@ -536,7 +536,7 @@ knh_dict_t *knh_dictset_malloc(Ctx *ctx, size_t init)
 
 #define _new_DictSet(ctx, c)   new_DictSet0(ctx, c)
 
-DictSet* new_DictSet0(Ctx *ctx, knh_int_t capacity)
+DictSet* new_DictSet0(Ctx *ctx, knh_intptr_t capacity)
 {
 	knh_DictSet_t *o = (knh_DictSet_t*)new_hObject(ctx, FLAG_DictSet, CLASS_DictSet, CLASS_DictSet);
 	o->_list = knh_dict_malloc(ctx, capacity, knh_dictset_finit, knh_dictset_ftraverse, knh_dict_fcmp);
@@ -563,7 +563,7 @@ String* knh_DictSet_keyAt(DictSet *o, size_t n)
 
 /* ------------------------------------------------------------------------ */
 
-knh_uint_t knh_DictSet_valueAt(DictSet *o, size_t n)
+knh_uintptr_t knh_DictSet_valueAt(DictSet *o, size_t n)
 {
 	KNH_ASSERT(n < o->size);
 	return o->list[n].value;
@@ -592,23 +592,23 @@ String *new_String__DictSet(Ctx *ctx, DictSet *o, knh_bytes_t key)
 
 /* ------------------------------------------------------------------------ */
 
-knh_uint_t knh_DictSet_get__b(DictSet *o, knh_bytes_t key)
+knh_uintptr_t knh_DictSet_get__b(DictSet *o, knh_bytes_t key)
 {
-	knh_int_t loc = knh_dict_index_b(o->_list, o->size, o->fcmp, key);
+	knh_intptr_t loc = knh_dict_index_b(o->_list, o->size, o->fcmp, key);
 	return (loc == -1) ? 0 : o->list[loc].value;
 }
 
 /* ------------------------------------------------------------------------ */
 
-knh_uint_t knh_DictSet_get(Ctx *ctx, DictSet *o, String *key)
+knh_uintptr_t knh_DictSet_get(Ctx *ctx, DictSet *o, String *key)
 {
-	knh_int_t loc = knh_dict_index_b(o->_list, o->size, o->fcmp, knh_String_tobytes(key));
+	knh_intptr_t loc = knh_dict_index_b(o->_list, o->size, o->fcmp, knh_String_tobytes(key));
 	return (loc == -1) ? 0 : o->list[loc].value;
 }
 
 /* ------------------------------------------------------------------------ */
 
-void knh_DictSet_append(Ctx *ctx, DictSet *o, String *key, knh_uint_t n)
+void knh_DictSet_append(Ctx *ctx, DictSet *o, String *key, knh_uintptr_t n)
 {
 	if(o->_list == NULL) {
 		o->_list = knh_dict_malloc(ctx, 8, knh_dictmap_finit, knh_dictmap_ftraverse, knh_dict_fcmp);
@@ -627,7 +627,7 @@ void knh_DictSet_append(Ctx *ctx, DictSet *o, String *key, knh_uint_t n)
 
 /* ------------------------------------------------------------------------ */
 
-void knh_DictSet_set(Ctx *ctx, DictSet *o, String *key, knh_uint_t n)
+void knh_DictSet_set(Ctx *ctx, DictSet *o, String *key, knh_uintptr_t n)
 {
 	int loc = knh_dict_index_b(o->_list, o->size, o->fcmp, knh_String_tobytes(key));
 	if(loc != -1) {
