@@ -83,7 +83,7 @@ void knh_OutputStream_putc(Ctx *ctx, OutputStream *o, int ch)
 	knh_Bytes_putc(ctx, ba, ch);
 	if(!knh_OutputStream_isStoringBuffer(o) && ba->size > DP(o)->driver.bufsiz) {
 		DP(o)->driver.fwrite(ctx, DP(o)->fd, (char*)(ba)->buf, (ba)->size);
-		knh_Bytes_clear(ba);
+		knh_Bytes_clear(ba, 0);
 	}
 	DP(o)->size++;
 }
@@ -97,7 +97,7 @@ void knh_OutputStream_write(Ctx *ctx, OutputStream *o, knh_bytes_t buf)
 	knh_Bytes_write(ctx, ba, buf);
 	if(!knh_OutputStream_isStoringBuffer(o) && ba->size > DP(o)->driver.bufsiz) {
 		DP(o)->driver.fwrite(ctx, DP(o)->fd, (char*)(ba)->buf, (ba)->size);
-		knh_Bytes_clear(ba);
+		knh_Bytes_clear(ba, 0);
 	}
 	DP(o)->size += buf.len;
 }
@@ -110,7 +110,7 @@ void knh_OutputStream_flush(Ctx *ctx, OutputStream *o)
 	if(!knh_OutputStream_isStoringBuffer(o)) {
 		Bytes *ba = DP(o)->ba;
 		DP(o)->driver.fwrite(ctx, DP(o)->fd, (char*)(ba)->buf, (ba)->size);
-		knh_Bytes_clear(ba);
+		knh_Bytes_clear(ba, 0);
 	}
 }
 
@@ -120,7 +120,7 @@ void knh_OutputStream_flush(Ctx *ctx, OutputStream *o)
 void knh_OutputStream_clear(Ctx *ctx, OutputStream *o)
 {
 	if(knh_OutputStream_isStoringBuffer(o)) {
-		knh_Bytes_clear(DP(o)->ba);
+		knh_Bytes_clear(DP(o)->ba, 0);
 	}
 }
 
@@ -179,10 +179,7 @@ void knh_OutputStream_print_(Ctx *ctx, OutputStream *o, knh_bytes_t str, knh_boo
 			knh_OutputStream_write(ctx, o, str);
 		}
 		else {
-			Bytes *ba = knh_Context_openBConvBuf(ctx);
-			knh_BytesConv_conv(ctx, DP(o)->bconv, str, ba);
-			knh_OutputStream_write(ctx, o, knh_Bytes_tobytes(ba));
-			knh_Context_closeBConvBuf(ctx, ba);
+			knh_OutputStream_write__bconv(ctx, o, str);
 		}
 	}
 	if(isnl) {
