@@ -102,7 +102,7 @@ KNHAPI(void) knh_write_TAB(Ctx *ctx, OutputStream *w)
 
 KNHAPI(void) knh_write_BOL(Ctx *ctx, OutputStream *w)
 {
-	knh_int_t i, n = DP(w)->indent;
+	knh_intptr_t i, n = DP(w)->indent;
 	for(i = 0; i < n; i++) knh_write_TAB(ctx, w);
 	knh_OutputStream_setBOL(w, 0);
 }
@@ -126,16 +126,16 @@ void knh_write__p(Ctx *ctx, OutputStream *w, void *ptr)
 
 /* ------------------------------------------------------------------------ */
 
-void knh_write__ifmt(Ctx *ctx, OutputStream *w, char *fmt, knh_int_t n)
+void knh_write__ifmt(Ctx *ctx, OutputStream *w, char *fmt, knh_intptr_t n)
 {
 	char buf[KNH_INT_FMTSIZ];
 	knh_snprintf(buf, sizeof(buf), fmt, n);
 	knh_write(ctx, w, B(buf));
 }
 
-#define _knh_write__i(ctx, w, n)   knh_write__ifmt(ctx, w, KNH_INT_FMT, n)
+#define _knh_write__i(ctx, w, n)   knh_write__ifmt(ctx, w, KNH_INTPTR_FMT, n)
 #define _knh_write__u(ctx, w, n)   knh_write__ifmt(ctx, w, KNH_UINT_FMT, n)
-#define _knh_write__x(ctx, w, n)   knh_write__ifmt(ctx, w, KNH_INT_FMTX, n)
+#define _knh_write__x(ctx, w, n)   knh_write__ifmt(ctx, w, KNH_INTPTR_FMTX, n)
 
 /* ------------------------------------------------------------------------ */
 
@@ -151,7 +151,7 @@ void knh_write__ffmt(Ctx *ctx, OutputStream *w, char *fmt, knh_float_t n)
 
 /* ------------------------------------------------------------------------ */
 
-void knh_write_integerfmt(Ctx *ctx, OutputStream *w, char *fmt, knh_integer_t n)
+void knh_write_integerfmt(Ctx *ctx, OutputStream *w, char *fmt, knh_int_t n)
 {
 	char buf[KNH_INT_FMTSIZ];
 	knh_snprintf(buf, sizeof(buf), fmt, n);
@@ -163,8 +163,8 @@ void knh_write_integerfmt(Ctx *ctx, OutputStream *w, char *fmt, knh_integer_t n)
 
 void knh_write__flag(Ctx *ctx, OutputStream *w, knh_flag_t flag)
 {
-	knh_int_t i;
-	knh_flag_t f = KNH_FLAG15;
+	knh_intptr_t i;
+	knh_flag_t f = 1 << 15;
 	for(i = 0; i < 16; i++) {
 		if(i > 0 && i % 8 == 0) knh_putc(ctx, w, ' ');
 		if((f & flag) == f) {
@@ -308,16 +308,16 @@ KNHAPI(void) knh_printf(Ctx *ctx, OutputStream *w, char *fmt, ...)
 			switch(ch) {
 				case '\0' : return ;
 				case 'd':
-					knh_write__i(ctx, w, (knh_int_t)va_arg(args, knh_int_t));
+					knh_write__i(ctx, w, (knh_intptr_t)va_arg(args, knh_intptr_t));
 					break;
 
 				case 'u':
-					knh_write__u(ctx, w, (knh_uint_t)va_arg(args, knh_uint_t));
+					knh_write__u(ctx, w, (knh_uintptr_t)va_arg(args, knh_uintptr_t));
 					break;
 
-				case 'x':
-					knh_write__x(ctx, w, (knh_uint_t)va_arg(args, knh_uint_t));
-					break;
+//				case 'x':
+//					knh_write__x(ctx, w, (knh_uintptr_t)va_arg(args, knh_uintptr_t));
+//					break;
 
 				case 'f':
 					knh_write__f(ctx, w, (knh_float_t)va_arg(args, double));
