@@ -47,7 +47,7 @@ extern "C" {
 /* ======================================================================== */
 /* [hcode] */
 
-knh_hcode_t knh_string_hash(knh_uchar_t *buf, knh_size_t len)
+knh_hcode_t knh_string_hash(knh_uchar_t *buf, size_t len)
 {
 	knh_hcode_t h = len;
 	size_t i;
@@ -180,7 +180,7 @@ String *new_StringX(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign)
 		TODO();
 		return new_String(ctx, t, orign);
 	}
-//	StringUnit *u = (StringUnit*)ctx->tClass[cid].cspec;
+//	StringUnit *u = (StringUnit*)ctx->share->ClassTable[cid].cspec;
 //	KNH_ASSERT(IS_StringUnit(u));
 //		if(DP(u)->fbconv != NULL) {
 //		return new_String__fcnv(ctx, DP(u)->)
@@ -205,10 +205,10 @@ String *new_StringX(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign)
 
 /* ------------------------------------------------------------------------ */
 
-String *new_String__integer(Ctx *ctx, knh_integer_t n)
+String *new_String__integer(Ctx *ctx, knh_int_t n)
 {
 	char buf[KNH_INTUNIT_BUFSIZ];
-	knh_snprintf(buf, sizeof(buf), KNH_INTEGER_FMT, n);
+	knh_snprintf(buf, sizeof(buf), KNH_INT_FMT, n);
 	return new_String(ctx, B(buf), NULL);
 }
 
