@@ -413,7 +413,7 @@ void KNH_ASM_BOX(Ctx *ctx, Asm *abr, knh_type_t atype, int a)
 	if(knh_rtti_issync(abr, a)) return;
 	knh_class_t cid = CLASS_type(atype);
 	KNH_ASSERT_cid(cid);
-	knh_class_t bcid = ctx->tClass[cid].bcid;
+	knh_class_t bcid = ctx->share->ClassTable[cid].bcid;
 	if(bcid == CLASS_Boolean || bcid == CLASS_Int || bcid == CLASS_Float) {
 		if(IS_NNTYPE(atype)) {
 			KNH_ASM_BOX_(ctx, abr, a, cid);
@@ -433,7 +433,7 @@ void KNH_ASM_NNBOX(Ctx *ctx, Asm *abr, knh_type_t atype, int a)
 	if(knh_rtti_issync(abr, a)) return;
 	knh_class_t cid = CLASS_type(atype);
 	KNH_ASSERT_cid(cid);
-	knh_class_t bcid = ctx->tClass[cid].bcid;
+	knh_class_t bcid = ctx->share->ClassTable[cid].bcid;
 	//DBG2_P("atype=%s%s", TYPEQN(atype));
 	if(bcid == CLASS_Boolean || bcid == CLASS_Int || bcid == CLASS_Float) {
 		if(IS_NNTYPE(atype)) {
@@ -1156,7 +1156,7 @@ int knh_StmtOP_checkConst(Ctx *ctx, Stmt *stmt, knh_methodn_t *mn, int swap)
 /* ------------------------------------------------------------------------ */
 
 static
-knh_integer_t TERMs_integer(Stmt *stmt, size_t n)
+knh_int_t TERMs_integer(Stmt *stmt, size_t n)
 {
 	Token *tk = DP(stmt)->tokens[n];
 	KNH_ASSERT(SP(tk)->tt == TT_CONST);
@@ -1221,7 +1221,7 @@ int knh_StmtOP_asm(Ctx *ctx, Stmt *stmt, Asm *abr, knh_type_t reqt, int sfpidx)
 		if(IS_OPSIM(mn)) {
 			if(knh_StmtOP_checkConst(ctx, stmt, &mn, /*swap*/ 1)) {
 				int a = TERMs_putSTACK(ctx, stmt, 1, abr, NNTYPE_Int, local + 1);
-				knh_integer_t b = TERMs_integer(stmt, 2);
+				knh_int_t b = TERMs_integer(stmt, 2);
 				switch(mn) {
 				case METHODN_opAdd:
 					KNH_ASM_iADDn_(ctx, abr, sfi_(sfpidx), sfi_(a), b);
@@ -1285,7 +1285,7 @@ int knh_StmtOP_asm(Ctx *ctx, Stmt *stmt, Asm *abr, knh_type_t reqt, int sfpidx)
 		else if(IS_OPASIM(mn)) {
 			if(knh_StmtOP_checkConst(ctx, stmt, &mn, /*swap*/ 0)) {
 				int a = TERMs_putSTACK(ctx, stmt, 1, abr, NNTYPE_Int, local + 1);
-				knh_integer_t b = TERMs_integer(stmt, 2);
+				knh_int_t b = TERMs_integer(stmt, 2);
 				switch(mn) {
 				case METHODN_opSub:
 					KNH_ASM_iSUBn_(ctx, abr, sfi_(sfpidx), sfi_(a), b);
@@ -1987,7 +1987,7 @@ void knh_StmtFOREACH_asm(Ctx *ctx, Stmt *stmt, Asm *abr)
 	DBG2_P("**(%d)ntype=%s%s (%d)itrtype=%s%s **", DP(tkn)->index, TYPEQN(DP(tkn)->type), DP(tkitr)->index, TYPEQN(DP(tkitr)->type));
 	knh_class_t ncid = CLASS_type(DP(tkn)->type);
 	knh_class_t itrcid = CLASS_type(DP(tkitr)->type);
-	KNH_ASSERT_cid(itrcid); itrcid = ctx->tClass[itrcid].p1;
+	KNH_ASSERT_cid(itrcid); itrcid = ctx->share->ClassTable[itrcid].p1;
 	if(ncid == itrcid || ncid == CLASS_Any || knh_class_instanceof(ctx, ncid, itrcid)) {
 		KNH_ASM_NEXT_(ctx, abr, lbend, sfi_(DP(tkn)->index), sfi_(DP(tkitr)->index), sfi_(DP(abr)->stack));
 	}
