@@ -1603,7 +1603,7 @@ static Term *new_TermEXPR(Ctx *ctx, knh_tokens_t *tc, int lr)
 			else if(DP(ts[oc])->tt_next == TT_NAME && ISB(knh_Token_tobytes(ctx, ts[oc+1]), "byte") && DP(ts[oc+1])->tt_next == TT_BRANCET) {
 				stmt = new_Stmt(ctx, 0, STT_NEW);
 				knh_Stmt_add(ctx, stmt, TM(new_TokenMN(ctx, FL(ts[oc]), METHODN_new)));
-				knh_Stmt_add(ctx, stmt, TM(new_Token__S(ctx, FL(ts[oc]), TT_TYPEN, ctx->tClass[CLASS_Bytes].sname)));
+				knh_Stmt_add(ctx, stmt, TM(new_Token__S(ctx, FL(ts[oc]), TT_TYPEN, ctx->share->ClassTable[CLASS_Bytes].sname)));
 				pc = oc + 2;
 				KNH_ASSERT(SP(ts[pc])->tt == TT_BRANCET);
 				SP(ts[pc])->tt = TT_PARENTHESIS;
@@ -2373,7 +2373,7 @@ static void knh_Stmt_add_EXTENDS(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		knh_Stmt_add_CLASSN(ctx, o, tc);
 	}
 	else {
-		knh_Stmt_add_S(ctx, o, TT_TYPEN, ctx->tClass[CLASS_Object].sname);
+		knh_Stmt_add_S(ctx, o, TT_TYPEN, ctx->share->ClassTable[CLASS_Object].sname);
 	}
 	if(tc->c < tc->e && SP(tc->ts[tc->c])->tt == TT_IMPLEMENTS) {
 		tc->c += 1;
