@@ -46,14 +46,14 @@ knh_io_t knh_iodrv_open__NOP(Ctx *ctx, InputStream *in, OutputStream *out, knh_b
 
 /* ------------------------------------------------------------------------ */
 
-static knh_int_t knh_iodrv_read__NOP(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz)
+static knh_intptr_t knh_iodrv_read__NOP(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz)
 {
 	return 0;
 }
 
 /* ------------------------------------------------------------------------ */
 
-static knh_int_t knh_iodrv_write__NOP(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz)
+static knh_intptr_t knh_iodrv_write__NOP(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz)
 {
 	return bufsiz;
 }
@@ -86,7 +86,7 @@ static knh_io_t knh_iodrv_open__FILE(Ctx *ctx, InputStream *in, OutputStream *ou
 /* ------------------------------------------------------------------------ */
 
 static
-knh_int_t knh_iodrv_read__FILE(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz)
+knh_intptr_t knh_iodrv_read__FILE(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz)
 {
 	FILE *fp = (FILE*)fd;
 	size_t ssize = fread(buf, 1, bufsiz, fp);
@@ -96,7 +96,7 @@ knh_int_t knh_iodrv_read__FILE(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz)
 /* ------------------------------------------------------------------------ */
 
 static
-knh_int_t knh_iodrv_write__FILE(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz)
+knh_intptr_t knh_iodrv_write__FILE(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz)
 {
 	FILE *fp = (FILE*)fd;
 	size_t ssize = fwrite(buf, 1, bufsiz, fp);
@@ -191,11 +191,11 @@ InputStream *new_InputStream__stdio(Ctx *ctx, FILE *fp, String *enc)
 	KNH_ASSERT(fp == stdin);
 	DP(o)->driver = IO__stdio;
 	knh_InputStream_setSTDIN(o, 1);
-	KNH_SETv(ctx, DP(o)->urn, TS_DEVSTDIN);
 	DP(o)->fp = fp;
 	DP(o)->bufsiz = 0;
 	DP(o)->bufpos = 0;
 	DP(o)->bufend = 0;  /* empty */
+	KNH_SETv(ctx, DP(o)->urn, TS_DEVSTDIN);
 	knh_InputStream_setEncoding(ctx, o, enc);
 	return o;
 }
