@@ -40,10 +40,10 @@ extern "C" {
 
 int konoha_existsConst(Ctx *ctx, knh_bytes_t name)
 {
-	DictMap *tcmap = DP(ctx->sys)->tConstDictMap;
-	KNH_LOCK(ctx, ctx->tableLock);
+	DictMap *tcmap = DP(ctx->sys)->GlobalConstDictMap;
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
 	int res = knh_DictMap_index__b(tcmap, name);
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 	return (res != -1);
 }
 
@@ -51,10 +51,10 @@ int konoha_existsConst(Ctx *ctx, knh_bytes_t name)
 
 Object *konoha_getConst(Ctx *ctx, knh_bytes_t name)
 {
-	DictMap *tcmap = DP(ctx->sys)->tConstDictMap;
-	KNH_LOCK(ctx, ctx->tableLock);
+	DictMap *tcmap = DP(ctx->sys)->GlobalConstDictMap;
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
 	Object *value = knh_DictMap_get__b(ctx, tcmap, name);
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 	return value;
 }
 
@@ -62,52 +62,52 @@ Object *konoha_getConst(Ctx *ctx, knh_bytes_t name)
 
 void konoha_addConst(Ctx *ctx, String *name, Object *value)
 {
-	DictMap *tcmap = DP(ctx->sys)->tConstDictMap;
-	KNH_LOCK(ctx, ctx->tableLock);
+	DictMap *tcmap = DP(ctx->sys)->GlobalConstDictMap;
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
 	knh_DictMap_append(ctx, tcmap, name, value);
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 }
 
 /* ------------------------------------------------------------------------ */
 
 KNHAPI(void) konoha_loadIntConstData(Ctx *ctx, knh_IntConstData_t *data)
 {
-	DictMap *tcmap = DP(ctx->sys)->tConstDictMap;
-	KNH_LOCK(ctx, ctx->tableLock);
+	DictMap *tcmap = DP(ctx->sys)->GlobalConstDictMap;
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
 	while(data->name != NULL) {
 		String *n = new_String__T(ctx, data->name);
 		knh_DictMap_append(ctx, tcmap, n, UP(new_Int(ctx, data->ivalue)));
 		data++;
 	}
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 }
 
 /* ------------------------------------------------------------------------ */
 
 KNHAPI(void) konoha_loadFloatConstData(Ctx *ctx, knh_FloatConstData_t *data)
 {
-	DictMap *tcmap = DP(ctx->sys)->tConstDictMap;
-	KNH_LOCK(ctx, ctx->tableLock);
+	DictMap *tcmap = DP(ctx->sys)->GlobalConstDictMap;
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
 	while(data->name != NULL) {
 		String *n = new_String__T(ctx, data->name);
 		knh_DictMap_append(ctx, tcmap, n, UP(new_Float(ctx, data->fvalue)));
 		data++;
 	}
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 }
 
 /* ------------------------------------------------------------------------ */
 
 KNHAPI(void) konoha_loadStringConstData(Ctx *ctx, knh_StringConstData_t *data)
 {
-	DictMap *tcmap = DP(ctx->sys)->tConstDictMap;
-	KNH_LOCK(ctx, ctx->tableLock);
+	DictMap *tcmap = DP(ctx->sys)->GlobalConstDictMap;
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
 	while(data->name != NULL) {
 		String *n = new_String__T(ctx, data->name);
 		knh_DictMap_append(ctx, tcmap, n, UP(new_String__T(ctx, data->value)));
 		data++;
 	}
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 }
 
 ///* ------------------------------------------------------------------------ */
@@ -127,10 +127,10 @@ KNHAPI(void) konoha_loadStringConstData(Ctx *ctx, knh_StringConstData_t *data)
 
 void knh_Const__man(Ctx *ctx, knh_class_t cid, OutputStream *w)
 {
-	DictMap *tcmap = DP(ctx->sys)->tConstDictMap;
+	DictMap *tcmap = DP(ctx->sys)->GlobalConstDictMap;
 	KNH_ASSERT_cid(cid);
-	knh_bytes_t n = knh_String_tobytes(ctx->tClass[cid].lname);
-	KNH_LOCK(ctx, ctx->tableLock);
+	knh_bytes_t n = knh_String_tobytes(ctx->share->ClassTable[cid].lname);
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
 	size_t i, size = knh_DictMap_size(tcmap);
 	int hasCaption = 0;
 	for(i = 0; i < size; i++) {
@@ -143,7 +143,7 @@ void knh_Const__man(Ctx *ctx, knh_class_t cid, OutputStream *w)
 			knh_printf(ctx, w, "\t%B: %O\n", knh_bytes_last(cn, knh_bytes_index(cn, '.')+1), knh_DictMap_valueAt(tcmap, i));
 		}
 	}
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 }
 
 /* ======================================================================== */
@@ -164,7 +164,7 @@ Object *konoha_getSystemConst(Ctx *ctx, int n)
 		case _KNH_SYS_STDIN:   return (Object*)((ctx)->in);
 		case _KNH_SYS_STDOUT:  return (Object*)((ctx)->out);
 		case _KNH_SYS_STDERR:  return (Object*)((ctx)->err);
-		case _KNH_SYS_OS:      return (Object*)konoha_getClassDefaultValue(ctx, CLASS_System);
+		case _KNH_SYS_OS:      return (Object*)konoha_geClassTableDefaultValue(ctx, CLASS_System);
 		case _KNH_SYS_SCRIPT:  return (Object*)knh_NameSpace_getScript(ctx, (ctx)->ns);
 	}
 	DBG_P("unknown system const n=%d", n);
@@ -214,12 +214,12 @@ knh_fieldn_t knh_tfieldn_common(Ctx *ctx, knh_bytes_t n, knh_fieldn_t def)
 	knh_format_nzname(buf, sizeof(buf), n);
 	knh_bytes_t tname = B(buf);
 
-	knh_index_t idx = knh_DictIdx_index(ctx, DP(ctx->sys)->tfieldnDictIdx, tname);
+	knh_index_t idx = knh_DictIdx_index(ctx, DP(ctx->sys)->FieldNameDictIdx, tname);
 	if(idx == -1) {
 		if(def == FIELDN_NEWID) {
 			String *s = new_String(ctx, tname, NULL);
 			knh_fieldn_t fn =
-				(knh_fieldn_t)knh_DictIdx_add__fast(ctx, DP(ctx->sys)->tfieldnDictIdx, s);
+				(knh_fieldn_t)knh_DictIdx_add__fast(ctx, DP(ctx->sys)->FieldNameDictIdx, s);
 			if(fn == (knh_fieldn_t)-1) {  /* Integer overflowed */
 				KNH_THROWs(ctx, "OutOfMemory!!: Too many field names");
 			}
@@ -289,9 +289,9 @@ char *knh_format_newFMT(char *buf, size_t bufsiz, knh_bytes_t t, int dot, char *
 
 String *konoha_getFieldName(Ctx *ctx, knh_fieldn_t fn)
 {
-	KNH_LOCK(ctx, ctx->tableLock);
-	String *s = (String*)knh_DictIdx_get__fast(DP(ctx->sys)->tfieldnDictIdx, FIELDN_UNMASK(fn));
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+	String *s = (String*)knh_DictIdx_get__fast(DP(ctx->sys)->FieldNameDictIdx, FIELDN_UNMASK(fn));
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 	DBG_(
 	if(IS_NULL(s)) {
 		DBG_P("unknown fn=%d", (int)FIELDN_UNMASK(fn));
@@ -334,11 +334,11 @@ knh_fieldn_t knh_tName_get_fnq(Ctx *ctx, knh_bytes_t tname, knh_fieldn_t def)
 			}
 		}
 
-		idx = knh_DictIdx_index(ctx, DP(ctx->sys)->tfieldnDictIdx, tname);
+		idx = knh_DictIdx_index(ctx, DP(ctx->sys)->FieldNameDictIdx, tname);
 		if(idx == -1) {
 			if(def == FIELDN_NEWID) {
 				String *s = new_String(ctx, tname, NULL);
-				knh_fieldn_t fn = (knh_fieldn_t)knh_DictIdx_add__fast(ctx, DP(ctx->sys)->tfieldnDictIdx, s);
+				knh_fieldn_t fn = (knh_fieldn_t)knh_DictIdx_add__fast(ctx, DP(ctx->sys)->FieldNameDictIdx, s);
 				if(!(fn < KNH_FLAG_FN_U2)) {
 					KNH_THROWs(ctx, "OutOfMemory!!: Too many field names");
 				}
@@ -372,7 +372,7 @@ String *new_String__mn(Ctx *ctx, knh_methodn_t mn)
 		if(islower(buf[3])) buf[3] = toupper(buf[3]);
 		return new_String(ctx, B(buf), NULL);
 	}
-	String *s = (String*)knh_DictIdx_get__fast(DP(ctx->sys)->tfieldnDictIdx, FIELDN_UNMASK(mn));
+	String *s = (String*)knh_DictIdx_get__fast(DP(ctx->sys)->FieldNameDictIdx, FIELDN_UNMASK(mn));
 	if(IS_NULL(s)) {
 		return TS_EMPTY;
 	}
@@ -466,14 +466,14 @@ knh_format_cmethodn(Ctx *ctx, char *buf, size_t bufsiz, knh_class_t cid, knh_met
 
 knh_fileid_t konoha_getFileId(Ctx *ctx, knh_bytes_t t)
 {
-	KNH_LOCK(ctx, ctx->tableLock);
-	knh_index_t idx = knh_DictIdx_index(ctx, DP(ctx->sys)->tfileidDictIdx, t);
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+	knh_index_t idx = knh_DictIdx_index(ctx, DP(ctx->sys)->FileNameDictIdx, t);
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 	if(idx == -1) {
 		String *s = new_String(ctx, t, NULL);
-		KNH_LOCK(ctx, ctx->tableLock);
-		knh_fileid_t filen = (knh_fileid_t)knh_DictIdx_add__fast(ctx, DP(ctx->sys)->tfileidDictIdx, s);
-		KNH_UNLOCK(ctx, ctx->tableLock);
+		KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+		knh_fileid_t filen = (knh_fileid_t)knh_DictIdx_add__fast(ctx, DP(ctx->sys)->FileNameDictIdx, s);
+		KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 		return filen;
 	}
 	return (knh_fileid_t)idx;
@@ -483,9 +483,9 @@ knh_fileid_t konoha_getFileId(Ctx *ctx, knh_bytes_t t)
 
 String *konoha_getFileName(Ctx *ctx, knh_fileid_t fileid)
 {
-	KNH_LOCK(ctx, ctx->tableLock);
-	String *s = (String*)knh_DictIdx_get__fast(DP(ctx->sys)->tfileidDictIdx, fileid);
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+	String *s = (String*)knh_DictIdx_get__fast(DP(ctx->sys)->FileNameDictIdx, fileid);
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 	DBG_(
 		if(IS_NULL(s)) {
 			DBG_P("unknown fileid=%d", (int)fileid);
@@ -522,9 +522,9 @@ void konoha_addDriverAPI(Ctx *ctx, char *alias, knh_drvapi_t* p)
 	else {
 		knh_snprintf(bufn, sizeof(bufn), "%s:%02d", alias, p->type);
 	}
-	KNH_LOCK(ctx, ctx->tableLock);
-	knh_DictSet_set(ctx, DP(ctx->sys)->drvapiDictSet, new_String(ctx, B(bufn), NULL), (knh_uint_t)p);
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+	knh_DictSet_set(ctx, DP(ctx->sys)->DriversTableDictSet, new_String(ctx, B(bufn), NULL), (knh_uintptr_t)p);
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -534,9 +534,9 @@ knh_drvapi_t *konoha_getDriverAPI(Ctx *ctx, int type, knh_bytes_t name)
 	char bufn[CLASSNAME_BUFSIZ], bufn2[CLASSNAME_BUFSIZ];
 	knh_format_bytes(bufn2, sizeof(bufn2), name);
 	knh_snprintf(bufn, sizeof(bufn), "%s:%02d", bufn2, type);
-	KNH_LOCK(ctx, ctx->tableLock);
-	knh_drvapi_t *p = (knh_drvapi_t*)knh_DictSet_get__b(DP(ctx->sys)->drvapiDictSet, B(bufn));
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+	knh_drvapi_t *p = (knh_drvapi_t*)knh_DictSet_get__b(DP(ctx->sys)->DriversTableDictSet, B(bufn));
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 	return p;
 }
 
@@ -593,15 +593,15 @@ NameSpace *knh_System_loadPackage(Ctx *ctx, knh_bytes_t pkgname)
 	char buff[FILENAME_BUFSIZ];
 	char *fpath = knh_format_pscript(ctx, buff, sizeof(buff), pkgname);
 	if(fpath != NULL) {
-		KNH_LOCK(ctx, ctx->tableLock);
-		NameSpace *ns = (NameSpace*)knh_DictMap_get__b(ctx,  knh_sysnsDictMap, pkgname);
-		KNH_UNLOCK(ctx, ctx->tableLock);
+		KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+		NameSpace *ns = (NameSpace*)knh_DictMap_get__b(ctx,  DP(ctx->sys)->NameSpaceTableDictMap, pkgname);
+		KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 		if(IS_NULL(ns)) {
 			String *nsname = new_String(ctx, pkgname, NULL);
 			ns = new_NameSpace(ctx, knh_rootNameSpace, nsname);
-			KNH_LOCK(ctx, ctx->tableLock);
-			knh_DictMap_set(ctx, knh_sysnsDictMap, nsname, UP(ns));
-			KNH_UNLOCK(ctx, ctx->tableLock);
+			KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+			knh_DictMap_set(ctx, DP(ctx->sys)->NameSpaceTableDictMap, nsname, UP(ns));
+			KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 			NameSpace *curns = knh_Context_switchNameSpace(ctx, ns);
 			knh_NameSpace_load(ctx, ns, B(fpath), 1 /* isEval */);
 			knh_Context_switchNameSpace(ctx, curns);
@@ -623,18 +623,18 @@ NameSpace *knh_System_getNameSpace(Ctx *ctx, knh_bytes_t name)
 		return ctx->ns;
 	}
 	else {
-		KNH_LOCK(ctx, ctx->tableLock);
-		NameSpace *ns = (NameSpace*)knh_DictMap_get__b(ctx,  DP(ctx->sys)->tnameSpaceDictMap, name);
-		KNH_UNLOCK(ctx, ctx->tableLock);
+		KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+		NameSpace *ns = (NameSpace*)knh_DictMap_get__b(ctx,  DP(ctx->sys)->NameSpaceTableDictMap, name);
+		KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 		if(IS_NULL(ns)) {
 			ns = knh_System_loadPackage(ctx, name);
 			if(ns != NULL) return ns;
 		}
 		String *nsname = new_String(ctx, name, NULL);
 		ns = new_NameSpace(ctx, knh_rootNameSpace, nsname);
-		KNH_LOCK(ctx, ctx->tableLock);
-		knh_DictMap_set(ctx, DP(ctx->sys)->tnameSpaceDictMap, nsname, UP(ns));
-		KNH_UNLOCK(ctx, ctx->tableLock);
+		KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+		knh_DictMap_set(ctx, DP(ctx->sys)->NameSpaceTableDictMap, nsname, UP(ns));
+		KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 		return ns;
 	}
 }
@@ -646,20 +646,20 @@ KNHAPI(void) konoha_addClassSpecFunc(Ctx *ctx, char *urn, knh_fspec func)
 {
 	if(func != (knh_fspec)NULL) {
 		DBG2_P("adding.. '%s'", urn);
-		KNH_LOCK(ctx, ctx->tableLock);
-		knh_DictSet_set(ctx, knh_makespecDictSet, new_String__T(ctx, urn), (knh_uint_t)func);
-		KNH_UNLOCK(ctx, ctx->tableLock);
+		KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+		knh_DictSet_set(ctx, DP(ctx->sys)->SpecFuncDictSet, new_String__T(ctx, urn), (knh_uintptr_t)func);
+		KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 	}
 }
 /* ------------------------------------------------------------------------ */
 
-ClassSpec *konoha_getClassSpec(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn)
+ClassSpec *konoha_geClassTableSpec(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn)
 {
 	urn = knh_Runtime_aliasURN(ctx, urn);
 	DBG2_P("finding.. '%s'", urn.buf);
-	KNH_LOCK(ctx, ctx->tableLock);
-	knh_fspec func = (knh_fspec)knh_DictSet_get__b(knh_makespecDictSet, urn);
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+	knh_fspec func = (knh_fspec)knh_DictSet_get__b(DP(ctx->sys)->SpecFuncDictSet, urn);
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 	if(func != NULL) {
 		return func(ctx, bcid, NULL);
 	}
